unit libvlc5;

{$mode objfpc}
{$PACKRECORDS C}
{$LinkLib vlccore}
{$LinkLib vlc}

interface


type
  libvlc_instance_t_ptr          = type Pointer;
  libvlc_log_t_ptr               = type Pointer;
  libvlc_log_iterator_t_ptr      = type Pointer;
  libvlc_media_t_ptr             = type Pointer;
  libvlc_media_player_t_ptr      = type Pointer;
  libvlc_media_list_t_ptr        = type Pointer;
  libvlc_media_list_player_t_ptr = type Pointer;
  libvlc_media_library_t_ptr     = type Pointer;
  libvlc_media_discoverer_t_ptr  = type Pointer;
  libvlc_event_manager_t_ptr     = type Pointer;


type
  libvlc_time_t_ptr = ^libvlc_time_t;
  libvlc_time_t = int64;

type
  libvlc_log_message_t_ptr = ^libvlc_log_message_t;
  libvlc_log_message_t = record
    sizeof_msg:  LongWord;   (* sizeof() of message structure, *)
                             (* must be filled in by user      *)
    i_severity:  Integer;    (* 0=INFO, 1=ERR, 2=WARN, 3=DBG   *)
    psz_type:    PAnsiChar;  (* module type                    *)
    psz_name:    PAnsiChar;  (* module name                    *)
    psz_header:  PAnsiChar;  (* optional header                *)
    psz_message: PAnsiChar;  (* message                        *)
  end;

type
  libvlc_meta_t = (
    libvlc_meta_Title,
    libvlc_meta_Artist,
    libvlc_meta_Genre,
    libvlc_meta_Copyright,
    libvlc_meta_Album,
    libvlc_meta_TrackNumber,
    libvlc_meta_Description,
    libvlc_meta_Rating,
    libvlc_meta_Date,
    libvlc_meta_Setting,
    libvlc_meta_URL,
    libvlc_meta_Language,
    libvlc_meta_NowPlaying,
    libvlc_meta_Publisher,
    libvlc_meta_EncodedBy,
    libvlc_meta_ArtworkURL,
    libvlc_meta_TrackID
    // Add new meta types HERE
);

type
  libvlc_state_t = (
    libvlc_NothingSpecial = 0,
    libvlc_Opening        = 1,
    libvlc_Buffering      = 2,
    libvlc_Playing        = 3,
    libvlc_Paused         = 4,
    libvlc_Stopped        = 5,
    libvlc_Ended          = 6,
    libvlc_Error          = 7
);

const
  libvlc_media_option_trusted = $0002;
  libvlc_media_option_unique  = $0100;

type
  libvlc_track_type_t = (
    libvlc_track_unknown = -1,
    libvlc_track_audio   = 0,
    libvlc_track_video   = 1,
    libvlc_track_text    = 2
);

type
  libvlc_media_stats_t_ptr = ^libvlc_media_stats_t;
  libvlc_media_stats_t = record
    // Input
    i_read_bytes:          Integer;
    f_input_bitrate:       Single; // Float
    // Demux
    i_demux_read_bytes:    Integer;
    f_demux_bitrate:       Single;
    i_demux_corrupted:     Integer;
    i_demux_discontinuity: Integer;
    // Decoders
    i_decoded_video:       Integer;
    i_decoded_audio:       Integer;
    // Video Output
    i_displayed_pictures:  Integer;
    i_lost_pictures:       Integer;
    // Audio output
    i_played_abuffers:     Integer;
    i_lost_abuffers:       Integer;
    // Stream output
    i_sent_packets:        Integer;
    i_sent_bytes:          Integer;
    f_send_bitrate:        Single;
  end;

type
  libvlc_media_track_info_t_audio = record
    i_channels: LongWord;
    i_rate:     LongWord
  end;

type
  libvlc_media_track_info_t_video = record
    i_height: LongWord;
    i_width:  LongWord;
  end;

type
  libvlc_media_track_info_t_ptr = ^libvlc_media_track_info_t;
  libvlc_media_track_info_t = record
    // Codec fourcc
    i_codec:   LongWord;
    i_id:      Integer;
    i_type:    libvlc_track_type_t;

    // Codec specific
    i_profile: Integer;
    i_level:   Integer;

    case Byte of
      0: (audio: libvlc_media_track_info_t_audio);
      1: (video: libvlc_media_track_info_t_video);
  end;

type
  libvlc_track_description_t_ptr = ^libvlc_track_description_t;
  libvlc_track_description_t = record
    i_id:     Integer;
    psz_name: PAnsiChar;
    p_next:   libvlc_track_description_t_ptr;
 end;

type
  libvlc_audio_output_t_ptr = ^libvlc_audio_output_t;
  libvlc_audio_output_t = record
    psz_name:        PAnsiChar;
    psz_description: PAnsiChar;
    p_next:          libvlc_audio_output_t_ptr;
  end;

type
  libvlc_rectangle_t_ptr = ^libvlc_rectangle_t;
  libvlc_rectangle_t = record
    top:    Integer;
    left:   Integer;
    bottom: Integer;
    right:  Integer;
  end;

type
  libvlc_video_marquee_option_t = (
    libvlc_marquee_Enable = 0,
    libvlc_marquee_Text,		// string argument
    libvlc_marquee_Color,
    libvlc_marquee_Opacity,
    libvlc_marquee_Position,
    libvlc_marquee_Refresh,
    libvlc_marquee_Size,
    libvlc_marquee_Timeout,
    libvlc_marquee_X,
    libvlc_marquee_Y
  );

const
  libvlc_video_marquee_color_Default = $f0000000;
  libvlc_video_marquee_color_Black   = $00000000;
  libvlc_video_marquee_color_Gray    = $00808080;
  libvlc_video_marquee_color_Silver  = $00C0C0C0;
  libvlc_video_marquee_color_White   = $00FFFFFF;
  libvlc_video_marquee_color_Maroon  = $00800000;
  libvlc_video_marquee_color_Red     = $00FF0000;
  libvlc_video_marquee_color_Fuchsia = $00FF00FF;
  libvlc_video_marquee_color_Yellow  = $00FFFF00;
  libvlc_video_marquee_color_Olive   = $00808000;
  libvlc_video_marquee_color_Green   = $00008000;
  libvlc_video_marquee_color_Teal    = $00008080;
  libvlc_video_marquee_color_Lime    = $0000FF00;
  libvlc_video_marquee_color_Purple  = $00800080;
  libvlc_video_marquee_color_Navy    = $00000080;
  libvlc_video_marquee_color_Blue    = $000000FF;
  libvlc_video_marquee_color_Aqua    = $0000FFFF;

const
  libvlc_video_marquee_opacity_none   = 0;
  libvlc_video_marquee_opacity_medium = 128;
  libvlc_video_marquee_opacity_full   = 255;

const
  libvlc_video_marquee_position_Center       = 0;
  libvlc_video_marquee_position_Left         = 1;
  libvlc_video_marquee_position_Right        = 2;
  libvlc_video_marquee_position_Top          = 3;
  libvlc_video_marquee_position_Bottom       = 4;
  libvlc_video_marquee_position_Top_Left     = 5;
  libvlc_video_marquee_position_Top_Right    = 6;
  libvlc_video_marquee_position_Bottom_Left  = 7;
  libvlc_video_marquee_position_Bottom_Right = 8;

type
  libvlc_video_logo_option_t = (
    libvlc_logo_enable,
    libvlc_logo_file,           // < string argument, "file,d,t;file,d,t;..."
    libvlc_logo_x,
    libvlc_logo_y,
    libvlc_logo_delay,
    libvlc_logo_repeat,
    libvlc_logo_opacity,
    libvlc_logo_position
 );

(**
 * Audio device types
 *)

type
  libvlc_audio_output_device_types_t = (
    libvlc_AudioOutputDevice_Error  = -1,
    libvlc_AudioOutputDevice_Mono   =  1,
    libvlc_AudioOutputDevice_Stereo =  2,
    libvlc_AudioOutputDevice_2F2R   =  4,
    libvlc_AudioOutputDevice_3F2R   =  5,
    libvlc_AudioOutputDevice_5_1    =  6,
    libvlc_AudioOutputDevice_6_1    =  7,
    libvlc_AudioOutputDevice_7_1    =  8,
    libvlc_AudioOutputDevice_SPDIF  = 10);

type
  libvlc_audio_output_channel_t = (
    libvlc_AudioChannel_Error   = -1,
    libvlc_AudioChannel_Stereo  =  1,
    libvlc_AudioChannel_RStereo =  2,
    libvlc_AudioChannel_Left    =  3,
    libvlc_AudioChannel_Right   =  4,
    libvlc_AudioChannel_Dolbys  =  5
  );

type
  libvlc_playback_mode_t = (
    libvlc_playback_mode_default,
    libvlc_playback_mode_loop,
    libvlc_playback_mode_repeat
  );


(*
 ******************************************************************************
 * libvlc_event.h
 *******************************************************************************
 *)

type
  libvlc_event_type_t = (
    (* Append new event types at the end of a category.
     * Do not remove, insert or re-order any entry.
     * Keep this in sync with src/control/event.c:libvlc_event_type_name(). *)
    libvlc_MediaMetaChanged = 0,
    libvlc_MediaSubItemAdded,
    libvlc_MediaDurationChanged,
    libvlc_MediaParsedChanged,
    libvlc_MediaFreed,
    libvlc_MediaStateChanged,

    libvlc_MediaPlayerMediaChanged = $100,
    libvlc_MediaPlayerNothingSpecial,
    libvlc_MediaPlayerOpening,
    libvlc_MediaPlayerBuffering,
    libvlc_MediaPlayerPlaying,
    libvlc_MediaPlayerPaused,
    libvlc_MediaPlayerStopped,
    libvlc_MediaPlayerForward,
    libvlc_MediaPlayerBackward,
    libvlc_MediaPlayerEndReached,
    libvlc_MediaPlayerEncounteredError,
    libvlc_MediaPlayerTimeChanged,
    libvlc_MediaPlayerPositionChanged,
    libvlc_MediaPlayerSeekableChanged,
    libvlc_MediaPlayerPausableChanged,
    libvlc_MediaPlayerTitleChanged,
    libvlc_MediaPlayerSnapshotTaken,
    libvlc_MediaPlayerLengthChanged,

    libvlc_MediaListItemAdded = $200,
    libvlc_MediaListWillAddItem,
    libvlc_MediaListItemDeleted,
    libvlc_MediaListWillDeleteItem,

    libvlc_MediaListViewItemAdded = $300,
    libvlc_MediaListViewWillAddItem,
    libvlc_MediaListViewItemDeleted,
    libvlc_MediaListViewWillDeleteItem,

    libvlc_MediaListPlayerPlayed = $400,
    libvlc_MediaListPlayerNextItemSet,
    libvlc_MediaListPlayerStopped,

    libvlc_MediaDiscovererStarted = $500,
    libvlc_MediaDiscovererEnded,

    libvlc_VlmMediaAdded = $600,
    libvlc_VlmMediaRemoved,
    libvlc_VlmMediaChanged,
    libvlc_VlmMediaInstanceStarted,
    libvlc_VlmMediaInstanceStopped,
    libvlc_VlmMediaInstanceStatusInit,
    libvlc_VlmMediaInstanceStatusOpening,
    libvlc_VlmMediaInstanceStatusPlaying,
    libvlc_VlmMediaInstanceStatusPause,
    libvlc_VlmMediaInstanceStatusEnd,
    libvlc_VlmMediaInstanceStatusError
  );

(*
 * Types below declared only for preserve structure of libvlc_event_t record
 *)

type
  event_media_meta_changed_t = record
    meta_type: libvlc_meta_t;
  end;

type
  event_media_subitem_added_t = record
    new_child: libvlc_media_t_ptr;
  end;

type
  event_media_duration_changed_t = record
    new_duration: Int64;
  end;

type
  media_parsed_changed_t = record
    new_status: Integer;
  end;

type
  media_freed_t = record
    md: libvlc_media_t_ptr;
  end;

type
  media_state_changed_t = record
    new_state: libvlc_state_t;
  end;

type
  media_player_time_changed_t = record
    new_time: libvlc_time_t;
  end;

type
  media_player_position_changed_t = record
    new_position: Single; // float
  end;

type
  media_player_title_changed_t = record
    new_title: Integer;
  end;

type
  media_player_seekable_changed_t = record
    new_seekable: Integer;
  end;

type
  media_player_pausable_changed_t = record
    new_pausable: Integer;
  end;

type
  media_list_item_added_t = record
    item: libvlc_media_t_ptr;
    index: Integer;
  end;

type
  media_list_will_add_item_t = record
    item: libvlc_media_t_ptr;
    index: Integer;
  end;

type
  media_list_item_deleted_t = record
    item: libvlc_media_t_ptr;
    index: Integer;
  end;

type
  media_list_will_delete_item_t = record
    item: libvlc_media_t_ptr;
    index: Integer;
  end;

type
  media_list_player_next_item_set_t = record
    item: libvlc_media_t_ptr;
  end;

type
  media_player_snapshot_taken_t = record
    psz_filename: PAnsiChar;
  end;

type
  media_player_length_changed_t = record
    new_length: libvlc_time_t;
  end;

type
  vlm_media_event_t = record
    psz_media_name: PAnsiChar;
    psz_instance_name: PAnsiChar;
  end;

type
  media_player_media_changed_t = record
    new_media: libvlc_media_t_ptr;
  end;

type
  libvlc_event_t_ptr = ^libvlc_event_t;
  libvlc_event_t = record
    event_type: libvlc_event_type_t;
    p_obj:      Pointer;              (* Object emitting the event *)
    case Integer of
    // media descriptor
    00: (media_meta_changed:              event_media_meta_changed_t);
    01: (media_subitem_added:             event_media_subitem_added_t);
    02: (media_duration_changed:          event_media_duration_changed_t);
    03: (media_parsed_changed:            media_parsed_changed_t);
    04: (media_freed:                     media_freed_t);
    05: (media_state_changed:             media_state_changed_t);
    // media instance
    06: (media_player_time_changed:       media_player_time_changed_t);
    07: (media_player_position_changed:   media_player_position_changed_t);
    08: (media_player_title_changed:      media_player_title_changed_t);
    09: (media_player_seekable_changed:   media_player_seekable_changed_t);
    10: (media_player_pausable_changed:   media_player_pausable_changed_t);
    // media list
    11: (media_list_item_added:           media_list_item_added_t);
    12: (media_list_will_add_item:        media_list_will_add_item_t);
    13: (media_list_item_deleted:         media_list_item_deleted_t);
    14: (media_list_will_delete_item:     media_list_will_delete_item_t);
    // media list player
    15: (media_list_player_next_item_set: media_list_player_next_item_set_t);
    // snapshot taken
    16: (media_player_snapshot_taken:     media_player_snapshot_taken_t);
    // Length changed
    17: (media_player_length_changed:     media_player_length_changed_t);
    // VLM media
    18: (vlm_media_event:                 vlm_media_event_t);
    19: (media_player_media_changed:      media_player_media_changed_t);
  end;


{Callback function notification
param p_event the event triggering the callback}
type
  libvlc_event_callback_t = procedure(p_event: libvlc_event_t_ptr; data:  Pointer); cdecl;

{A human-readable error message for the last LibVLC error in the calling
thread. The resulting string is valid until another error occurs (at least
until the next LibVLC call).
warning
This will be NULL if there was no error.}
function libvlc_errmsg(): PAnsiChar; cdecl;

{Clears the LibVLC error status for the current thread. This is optional.
By default, the error status is automatically overriden when a new error
occurs, and destroyed when the thread exits.}
procedure libvlc_clearerr(); cdecl;

{Sets the LibVLC error status and message for the current thread.
Any previous error is overriden.
return a nul terminated string in any case}
function libvlc_vprinterr(fmt: PAnsiChar; ap: array of pointer): PAnsiChar; cdecl;

{Sets the LibVLC error status and message for the current thread.
Any previous error is overriden.
return a nul terminated string in any case}
function libvlc_printerr(fmt: PAnsiChar): PAnsiChar; cdecl;

{Create and initialize a libvlc instance.
param argc the number of arguments
param argv command-line-type arguments
return the libvlc instance or NULL in case of error}
function libvlc_new(argc: Integer; args: PPAnsiChar): libvlc_instance_t_ptr; cdecl;

{Decrement the reference count of a libvlc instance, and destroy it
if it reaches zero.
param p_libvlc_instance the instance to destroy}
procedure libvlc_release(p_libvlc_instance: libvlc_instance_t_ptr); cdecl;

{Increments the reference count of a libvlc instance.
The initial reference count is 1 after libvlc_new() returns.
param p_libvlc_instance the instance to reference}
procedure libvlc_retain(p_libvlc_instance: libvlc_instance_t_ptr); cdecl;

{Try to start a user interface for the libvlc instance.
param p_libvlc_instance the instance
param name interface name, or NULL for default
return 0 on success, -1 on error.}
function libvlc_add_intf(p_libvlc_instance: libvlc_instance_t_ptr; name: PAnsiChar): Integer; cdecl;

{Waits until an interface causes the instance to exit.
You should start at least one interface first, using libvlc_add_intf().
param p_libvlc_instance the instance}
procedure libvlc_wait(p_libvlc_instance: libvlc_instance_t_ptr); cdecl;

{Sets the application name. LibVLC passes this as the user agent string
when a protocol requires it.
param p_instance LibVLC instance
param name human-readable application name, e.g. "FooBar player 1.2.3"
param http HTTP User Agent, e.g. "FooBar/1.2.3 Python/2.6.0"
version LibVLC 1.1.1 or later}
procedure libvlc_set_user_agent(p_libvlc_instance: libvlc_instance_t_ptr;name: PAnsiChar;http: PAnsiChar); cdecl;

{Retrieve libvlc version.
Example: "1.1.0-git The Luggage"
return a string containing the libvlc version}
function libvlc_get_version(): PAnsiChar; cdecl;

{Retrieve libvlc compiler version.
Example: "gcc version 4.2.3 (Ubuntu 4.2.3-2ubuntu6)"
return a string containing the libvlc compiler version}
function libvlc_get_compiler(): PAnsiChar; cdecl;

{Retrieve libvlc changeset.
Example: "aa9bce0bc4"
return a string containing the libvlc changeset}
function libvlc_get_changeset(): PAnsiChar; cdecl;

{LibVLC emits asynchronous events.
Several LibVLC objects (such ref libvlc_instance_t as
ref libvlc_media_player_t) generate events asynchronously. Each of them
provides ref libvlc_event_manager_t event manager. You can subscribe to
events with libvlc_event_attach() and unsubscribe with
libvlc_event_detach().
Event manager that belongs to a libvlc object, and from whom events can
be received.}

{Register for an event notification.
param p_event_manager the event manager to which you want to attach to.
      Generally it is obtained by vlc_my_object_event_manager() where
      my_object is the object you want to listen to.
param i_event_type the desired event to which we want to listen
param f_callback the function to call when i_event_type occurs
param user_data user provided data to carry with the event
return 0 on success, ENOMEM on error}
function libvlc_event_attach(p_event_manager: libvlc_event_manager_t_ptr; i_event_type: libvlc_event_type_t;
  f_callback: libvlc_event_callback_t; user_data:Pointer): Integer; cdecl;

{Unregister an event notification.
param p_event_manager the event manager
param i_event_type the desired event to which we want to unregister
param f_callback the function to call when i_event_type occurs
param p_user_data user provided data to carry with the event}
procedure libvlc_event_detach(p_event_manager: libvlc_event_manager_t_ptr; i_event_type:    libvlc_event_type_t;
  f_callback: libvlc_event_callback_t; p_user_data: Pointer); cdecl;

{Get an event's type name.
param event_type the desired event}
function libvlc_event_type_name(event_type: libvlc_event_type_t): PAnsiChar; cdecl;

{libvlc_log_* functions provide access to the LibVLC messages log.
This is used for debugging or by advanced users.}
{Return the VLC messaging verbosity level.
param p_libvlc_instance libvlc instance
return verbosity level for messages}
function libvlc_get_log_verbosity(p_libvlc_instance: libvlc_instance_t_ptr): LongWord; cdecl;

{Set the VLC messaging verbosity level.
param p_libvlc_instance libvlc instance
param level log level}
procedure libvlc_set_log_verbosity(p_libvlc_instance: libvlc_instance_t_ptr; level: LongWord); cdecl;

{Open a VLC message log instance.
param p_libvlc_instance libvlc instance
return log message instance or NULL on error}
function libvlc_log_open(p_libvlc_instance: libvlc_instance_t_ptr): libvlc_log_t_ptr; cdecl;

{Close a VLC message log instance.
param p_log libvlc log instance or NULL}
procedure libvlc_log_close(p_log: libvlc_log_t_ptr); cdecl;

{Returns the number of messages in a log instance.
\param p_log libvlc log instance or NULL
return number of log messages, 0 if p_log is NULL}
function libvlc_log_count(p_log: libvlc_log_t_ptr): LongWord; cdecl;

{Clear a log instance.
All messages in the log are removed. The log should be cleared on a
regular basis to avoid clogging.
param p_log libvlc log instance or NULL}

procedure libvlc_log_clear(p_log: libvlc_log_t_ptr); cdecl;

{Allocate and returns a new iterator to messages in log.
param p_log libvlc log instance
return log iterator object or NULL on error}
function libvlc_log_get_iterator(p_log: libvlc_log_t_ptr): libvlc_log_iterator_t_ptr; cdecl;

{Release a previoulsy allocated iterator.
param p_iter libvlc log iterator or NULL}
procedure libvlc_log_iterator_free(p_log: libvlc_log_t_ptr); cdecl;

{Return whether log iterator has more messages.
param p_iter libvlc log iterator or NULL
return true if iterator has more message objects, else false}
function libvlc_log_iterator_has_next(p_iter: libvlc_log_iterator_t_ptr): LongInt; cdecl;

{Return the next log message.
The message contents must not be freed
param p_iter libvlc log iterator or NULL
param p_buffer log buffer
return log message object or NULL if none left}
function libvlc_log_iterator_next(p_iter: libvlc_log_iterator_t_ptr; p_buffer: libvlc_log_message_t_ptr): libvlc_log_message_t_ptr; cdecl;

{*****************************************************************************
libvlc_media.h
 ******************************************************************************}

{Create a media with a certain given media resource location.
see libvlc_media_release
param p_libvlc_instance the instance
param psz_mrl the MRL to read
return the newly created media or NULL on error}
function libvlc_media_new_location(p_libvlc_instance: libvlc_instance_t_ptr; psz_mrl: PAnsiChar): libvlc_media_t_ptr; cdecl;

{Create a media with a certain file path.
see libvlc_media_release
param p_libvlc_instance the instance
param path local filesystem path
return the newly created media or NULL on error}
function libvlc_media_new_path(p_libvlc_instance: libvlc_instance_t_ptr; path: PAnsiChar): libvlc_media_t_ptr; cdecl;

{Create a media as an empty node with a given name.
see libvlc_media_release
param p_libvlc_instance the instance
param psz_name the name of the node
return the new empty media or NULL on error}
function libvlc_media_new_as_node(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar): libvlc_media_t_ptr; cdecl;

{Add an option to the media.
This option will be used to determine how the media_player will
read the media. This allows to use VLC's advanced
reading/streaming options on a per-media basis.
The options are detailed in vlc --long-help, for instance "--sout-all"
param p_md the media descriptor
param ppsz_options the options (as a string)}
procedure libvlc_media_add_option(p_md: libvlc_media_t_ptr; ppsz_options: PAnsiChar); cdecl;

{Add an option to the media with configurable flags.
This option will be used to determine how the media_player will
read the media. This allows to use VLC's advanced
reading/streaming options on a per-media basis.
The options are detailed in vlc --long-help, for instance "--sout-all"
param p_md the media descriptor
param ppsz_options the options (as a string)
param i_flags the flags for this option}
procedure libvlc_media_add_option_flag(p_md: libvlc_media_t_ptr; ppsz_options: PAnsiChar;i_flags: LongWord); cdecl;

{Retain a reference to a media descriptor object (libvlc_media_t). Use
libvlc_media_release() to decrement the reference count of a
media descriptor object.
param p_md the media descriptor}
procedure libvlc_media_retain(p_md: libvlc_media_t_ptr); cdecl;

{Decrement the reference count of a media descriptor object. If the
reference count is 0, then libvlc_media_release() will release the
media descriptor object. It will send out an libvlc_MediaFreed event
to all listeners. If the media descriptor object has been released it
should not be used again.
param p_md the media descriptor}
procedure libvlc_media_release(p_md: libvlc_media_t_ptr); cdecl;

{Get the media resource locator (mrl) from a media descriptor object
param p_md a media descriptor object
return string with mrl of media descriptor object}
function libvlc_media_get_mrl(p_md: libvlc_media_t_ptr): PAnsiChar; cdecl;

{Duplicate a media descriptor object.
param p_md a media descriptor object.}
function libvlc_media_duplicate(p_md: libvlc_media_t_ptr): libvlc_media_t_ptr; cdecl;

{Read the meta of the media.
If the media has not yet been parsed this will return NULL.
This methods automatically calls libvlc_media_parse_async(), so after calling
it you may receive a libvlc_MediaMetaChanged event. If you prefer a synchronous
version ensure that you call libvlc_media_parse() before get_meta().
see libvlc_media_parse
see libvlc_media_parse_async
see libvlc_MediaMetaChanged
param p_md the media descriptor
param e_meta the meta to read
return the media's meta}
function libvlc_media_get_meta(p_md:   libvlc_media_t_ptr; e_meta: libvlc_meta_t): PAnsiChar; cdecl;

{Set the meta of the media (this function will not save the meta, call
libvlc_media_save_meta in order to save the meta)
param p_md the media descriptor
param e_meta the meta to write
param psz_value the media's meta}
procedure libvlc_media_set_meta(p_md: libvlc_media_t_ptr; e_meta: libvlc_meta_t; psz_value: PAnsiChar); cdecl;

{Save the meta previously set
param p_md the media desriptor
return true if the write operation was successfull}
function libvlc_media_save_meta(p_md: libvlc_media_t_ptr): Integer; cdecl;

{Get current state of media descriptor object. Possible media states
are defined in libvlc_structures.c ( libvlc_NothingSpecial=0,
libvlc_Opening, libvlc_Buffering, libvlc_Playing, libvlc_Paused,
libvlc_Stopped, libvlc_Ended,
libvlc_Error).
see libvlc_state_t
param p_meta_desc a media descriptor object
return state of media descriptor object}
function libvlc_media_get_state(p_meta_desc: libvlc_media_t_ptr): libvlc_state_t; cdecl;

{get the current statistics about the media
param p_md: media descriptor object
param p_stats: structure that contain the statistics about the media
               (this structure must be allocated by the caller)
return true if the statistics are available, false otherwise}
function libvlc_media_get_stats(p_md: libvlc_media_t_ptr; p_stats: libvlc_media_stats_t_ptr): Integer; cdecl;

{Get subitems of media descriptor object. This will increment
the reference count of supplied media descriptor object. Use
libvlc_media_list_release() to decrement the reference counting.
param p_md media descriptor object
return list of media descriptor subitems or NULL}
function libvlc_media_subitems(p_md: libvlc_media_t_ptr): libvlc_media_list_t_ptr; cdecl;

{Get event manager from media descriptor object.
NOTE: this function doesn't increment reference counting.
param p_md a media descriptor object
return event manager object}
function libvlc_media_event_manager(p_md: libvlc_media_t_ptr): libvlc_event_manager_t_ptr; cdecl;

{Get duration (in ms) of media descriptor object item.
param p_md media descriptor object
return duration of media item or -1 on error}
function libvlc_media_get_duration(p_md: libvlc_media_t_ptr): libvlc_time_t; cdecl;

{Parse a media.
This fetches (local) meta data and tracks information.
The method is synchronous.
see libvlc_media_parse_async
see libvlc_media_get_meta
see libvlc_media_get_tracks_info
param media media descriptor object}

procedure libvlc_media_parse(media: libvlc_media_t_ptr); cdecl;

{Parse a media.
This fetches (local) meta data and tracks information.
The method is the asynchronous of libvlc_media_parse().
To track when this is over you can listen to libvlc_MediaParsedChanged
event. However if the media was already parsed you will not receive this
event.
\see libvlc_media_parse
\see libvlc_MediaParsedChanged
\see libvlc_media_get_meta
\see libvlc_media_get_tracks_info
\param media media descriptor object}
procedure libvlc_media_parse_async(media: libvlc_media_t_ptr); cdecl;

{Get Parsed status for media descriptor object.
see libvlc_MediaParsedChanged
param p_md media descriptor object
return true if media object has been parsed otherwise it returns false}
function libvlc_media_is_parsed(p_md: libvlc_media_t_ptr): Integer; cdecl;

{Sets media descriptor's user_data. user_data is specialized data
accessed by the host application, VLC.framework uses it as a pointer to
an native object that references a libvlc_media_t pointer
param p_md media descriptor object
param p_new_user_data pointer to user data}
procedure libvlc_media_set_user_data(p_md: libvlc_media_t_ptr;p_new_user_data: Pointer); cdecl;

{Get media descriptor's user_data. user_data is specialized data
accessed by the host application, VLC.framework uses it as a pointer to
an native object that references a libvlc_media_t pointer
param p_md media descriptor object}
function libvlc_media_get_user_data(p_md: libvlc_media_t_ptr): Pointer; cdecl;

{Get media descriptor's elementary streams description
Note, you need to play the media _one_ time with --sout="#description"
Not doing this will result in an empty array, and doing it more than once
will duplicate the entries in the array each time. Something like this:
libvlc_media_player_t *player = libvlc_media_player_new_from_media(media);
libvlc_media_add_option_flag(media, "sout=\"#description\"");
libvlc_media_player_play(player);
// ... wait until playing
libvlc_media_player_release(player);
This is very likely to change in next release, and be done at the parsing
phase.
param media media descriptor object
param tracks address to store an allocated array of Elementary Streams
descriptions (must be freed by the caller)
return the number of Elementary Streams}
function libvlc_media_get_tracks_info(media: libvlc_media_t_ptr; var tracks: libvlc_media_track_info_t_ptr): Integer; cdecl;


{*******************************************************************************
libvlc_media_player.h
 *******************************************************************************}

{Create an empty Media Player object
param p_libvlc_instance the libvlc instance in which the Media Player
       should be created.
return a new media player object, or NULL on error.}
function libvlc_media_player_new(p_libvlc_instance: libvlc_instance_t_ptr): libvlc_media_player_t_ptr; cdecl;

{Create a Media Player object from a Media
param p_md the media. Afterwards the p_md can be safely destroyed.
return a new media player object, or NULL on error.}
function libvlc_media_player_new_from_media(p_md: libvlc_media_t_ptr): libvlc_media_player_t_ptr; cdecl;

{Release a media_player after use
Decrement the reference count of a media player object. If the
reference count is 0, then libvlc_media_player_release() will
release the media player object. If the media player object
has been released, then it should not be used again.
param p_mi the Media Player to free}
procedure libvlc_media_player_release(p_mi: libvlc_media_player_t_ptr); cdecl;

{Retain a reference to a media player object. Use
libvlc_media_player_release() to decrement reference count.
param p_mi media player object}
procedure libvlc_media_player_retain(p_mi: libvlc_media_player_t_ptr); cdecl;

{Set the media that will be used by the media_player. If any,
previous md will be released.
param p_mi the Media Player
param p_md the Media. Afterwards the p_md can be safely destroyed.}
procedure libvlc_media_player_set_media(p_mi: libvlc_media_player_t_ptr;p_md: libvlc_media_t_ptr); cdecl;

{Get the media used by the media_player.
param p_mi the Media Player
return the media associated with p_mi, or NULL if no media is associated}
// VLC_PUBLIC_API libvlc_media_tlibvlc_media_player_get_media( libvlc_media_player_t *p_mi );
function libvlc_media_player_get_media(p_mi: libvlc_media_player_t_ptr): libvlc_media_t_ptr; cdecl;

{Get the Event Manager from which the media player send event.
param p_mi the Media Player
return the event manager associated with p_mi}
function libvlc_media_player_event_manager(p_mi: libvlc_media_player_t_ptr): libvlc_event_manager_t_ptr; cdecl;

{is_playing
param p_mi the Media Player
return 1 if the media player is playing, 0 otherwise}
function libvlc_media_player_is_playing(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Play
param p_mi the Media Player
return 0 if playback started (and was already started), or -1 on error.}
function libvlc_media_player_play(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Pause or resume (no effect if there is no media)
param mp the Media Player
param do_pause play/resume if zero, pause if non-zero
version LibVLC 1.1.1 or later}
procedure libvlc_media_player_set_pause(p_mi: libvlc_media_player_t_ptr; do_pause: Integer); cdecl;

{Toggle pause (no effect if there is no media)
param p_mi the Media Player}
procedure libvlc_media_player_pause(p_mi: libvlc_media_player_t_ptr); cdecl;

{Stop (no effect if there is no media)
param p_mi the Media Player}
procedure libvlc_media_player_stop(p_mi: libvlc_media_player_t_ptr); cdecl;

{Set callbacks and private data to render decoded video to a custom area
in memory. Use libvlc_video_set_format() to configure the decoded format.
Whenever a new video frame needs to be decoded, the lock callback is
invoked. Depending on the video chroma, one or three pixel planes of
adequate dimensions must be returned via the second parameter. Those
planes must be aligned on 32-bytes boundaries.
When the video frame is decoded, the unlock callback is invoked. The
second parameter to the callback corresponds is the return value of the
lock callback. The third parameter conveys the pixel planes for convenience.
When the video frame needs to be shown, as determined by the media playback
clock, the display callback is invoked. The second parameter also conveys
the return value from the lock callback.
param mp the media player
param lock callback to allocate video memory
param unlock callback to release video memory
param opaque private pointer for the three callbacks (as first parameter)
version LibVLC 1.1.1 or later}

type
  lock_call_fun    = function(opaque: Pointer; plane: Pointer): Pointer;
  unlock_call_fun  = function(opaque: Pointer; picture: Pointer; plane: Pointer): Pointer;
  display_call_fun = function(opaque: Pointer; picture: Pointer): Pointer;

procedure libvlc_video_set_callbacks(p_mi: libvlc_media_player_t_ptr; lock: lock_call_fun; unlock: unlock_call_fun;
  display: display_call_fun; opaque: Pointer); cdecl;

{Set decoded video chroma and dimensions. This only works in combination with
libvlc_video_set_callbacks().
param mp the media player
param chroma a four-characters string identifying the chroma
              (e.g. "RV32" or "I420")
param width pixel width
param height pixel height
param pitch line pitch (in bytes)
version LibVLC 1.1.1 or later}
procedure libvlc_video_set_format(p_mi: libvlc_media_player_t_ptr; chroma: PAnsiChar; width: Longword; height: Longword; pitch: Longword); cdecl;

{Set the NSView handler where the media player should render its video output.
Use the vout called "macosx".
The drawable is an NSObject that follow the VLCOpenGLVideoViewEmbedding
protocol: }
 // \protocol VLCOpenGLVideoViewEmbedding <NSObject>
 // - (void)addVoutSubview:(NSView}view;
 // - (void)removeVoutSubview:(NSView}view;
 // \end
{
Or it can be an NSView object.
If you want to use it along with Qt4 see the QMacCocoaViewContainer. Then
the following code should work:
begincode
    NSView *video = [[NSView alloc] init];
    QMacCocoaViewContainer *container = new QMacCocoaViewContainer(video, parent);
    libvlc_media_player_set_nsobject(mp, video);
    [video release];
endcode
You can find a live example in VLCVideoView in VLCKit.framework.
\param p_mi the Media Player
\param drawable the drawable that is either an NSView or an object following
the VLCOpenGLVideoViewEmbedding protocol.}
procedure libvlc_media_player_set_nsobject(p_mi: libvlc_media_player_t_ptr; drawable: Pointer); cdecl;

{Get the NSView handler previously set with libvlc_media_player_set_nsobject().
\param p_mi the Media Player
\return the NSView handler or 0 if none where set}
function libvlc_media_player_get_nsobject(p_mi: libvlc_media_player_t_ptr): Pointer; cdecl;

{Set the agl handler where the media player should render its video output.
param p_mi the Media Player
param drawable the agl handler}
procedure libvlc_media_player_set_agl(p_mi: libvlc_media_player_t_ptr; drawable: LongWord); cdecl;

{Get the agl handler previously set with libvlc_media_player_set_agl().
param p_mi the Media Player
return the agl handler or 0 if none where set}
function libvlc_media_player_get_agl(p_mi: libvlc_media_player_t_ptr): LongWord; cdecl;

{Set an X Window System drawable where the media player should render its
video output. If LibVLC was built without X11 output support, then this has
no effects.
The specified identifier must correspond to an existing Input/Output class
X11 window. Pixmaps are <b>not</b> supported. The caller shall ensure that
the X11 server is the same as the one the VLC instance has been configured
with.
param p_mi the Media Player
param drawable the ID of the X window}
procedure libvlc_media_player_set_xwindow(p_mi: libvlc_media_player_t_ptr; drawable: LongWord); cdecl;

{Get the X Window System window identifier previously set with
libvlc_media_player_set_xwindow(). Note that this will return the identifier
even if VLC is not currently using it (for instance if it is playing an
audio-only input).
param p_mi the Media Player
return an X window ID, or 0 if none where set.}
function libvlc_media_player_get_xwindow(p_mi: libvlc_media_player_t_ptr): LongWord; cdecl;

{Set a Win32/Win64 API window handle (HWND) where the media player should
render its video output. If LibVLC was built without Win32/Win64 API output
support, then this has no effects.
param p_mi the Media Player
param drawable windows handle of the drawable}
procedure libvlc_media_player_set_hwnd(p_mi: libvlc_media_player_t_ptr; hwnd: THandle); cdecl;

{Get the Windows API window handle (HWND) previously set with
libvlc_media_player_set_hwnd(). The handle will be returned even if LibVLC
is not currently outputting any video to it.
\param p_mi the Media Player
\return a window handle or NULL if there are none.}
function libvlc_media_player_get_hwnd(p_mi: libvlc_media_player_t_ptr): THandle; cdecl;


{*******************************************************************************
bug This might go away ... to be replaced by a broader system */
 *******************************************************************************}

{Get the current movie length (in ms).
param p_mi the Media Player
return the movie length (in ms), or -1 if there is no media.}
function libvlc_media_player_get_length(p_mi: libvlc_media_player_t_ptr): libvlc_time_t; cdecl;

{Get the current movie time (in ms).
param p_mi the Media Player
return the movie time (in ms), or -1 if there is no media.}
function libvlc_media_player_get_time(p_mi: libvlc_media_player_t_ptr): libvlc_time_t; cdecl;

{Set the movie time (in ms). This has no effect if no media is being played.
Not all formats and protocols support this.
param p_mi the Media Player
param i_time the movie time (in ms).}
procedure libvlc_media_player_set_time(p_mi: libvlc_media_player_t_ptr; i_time: libvlc_time_t); cdecl;

{Get movie position.
param p_mi the Media Player
return movie position in range 0..1, or -1. in case of error}
function libvlc_media_player_get_position(p_mi: libvlc_media_player_t_ptr): Single; cdecl;

{Set movie position. This has no effect if playback is not enabled.
This might not work depending on the underlying input format and protocol.
param p_mi the Media Player
param f_pos the position in range 0..1}
procedure libvlc_media_player_set_position(p_mi:  libvlc_media_player_t_ptr; f_pos: Single); cdecl;

{Set movie chapter (if applicable).
param p_mi the Media Player
param i_chapter chapter number to play}
procedure libvlc_media_player_set_chapter(p_mi: libvlc_media_player_t_ptr; i_chapter: Integer); cdecl;

{Get movie chapter.
param p_mi the Media Player
return chapter number currently playing, or -1 if there is no media.}
function libvlc_media_player_get_chapter(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Get movie chapter count
param p_mi the Media Player
return number of chapters in movie, or -1.}
function libvlc_media_player_get_chapter_count(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Is the player able to play
param p_mi the Media Player
return boolean}
function libvlc_media_player_will_play(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Get title chapter count
param p_mi the Media Player
param i_title title
return number of chapters in title, or -1}
function libvlc_media_player_get_chapter_count_for_title(p_mi: libvlc_media_player_t_ptr; i_title: Integer): Integer; cdecl;

{Set movie title
param p_mi the Media Player
param i_title title number to play}
procedure libvlc_media_player_set_title(p_mi: libvlc_media_player_t_ptr; i_title: Integer); cdecl;

{Get movie title
param p_mi the Media Player
return title number currently playing, or -1}
function libvlc_media_player_get_title(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Get movie title count
param p_mi the Media Player
return title number count, or -1}
function libvlc_media_player_get_title_count(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Set previous chapter (if applicable)
param p_mi the Media Player}
procedure libvlc_media_player_previous_chapter(p_mi: libvlc_media_player_t_ptr); cdecl;

{Set next chapter (if applicable)
param p_mi the Media Player}
procedure libvlc_media_player_next_chapter(p_mi: libvlc_media_player_t_ptr); cdecl;

{Get the requested movie play rate.
warning Depending on the underlying media, the requested rate may be
different from the real playback rate.
param p_mi the Media Player
return movie play rate}
function libvlc_media_player_get_rate(p_mi: libvlc_media_player_t_ptr): Single; cdecl;

{Set movie play rate
param p_mi the Media Player
param rate movie play rate to set
return -1 if an error was detected, 0 otherwise (but even then, it might
not actually work depending on the underlying media protocol)}
function libvlc_media_player_set_rate(p_mi: libvlc_media_player_t_ptr; rate: Single): Integer; cdecl;

{Get current movie state
param p_mi the Media Player
return the current state of the media player (playing, paused, ...)
see libvlc_state_t}
function libvlc_media_player_get_state(p_mi: libvlc_media_player_t_ptr): libvlc_state_t; cdecl;

{Get movie fps rate
param p_mi the Media Player
return frames per second (fps) for this playing movie, or 0 if unspecified}
function libvlc_media_player_get_fps(p_mi: libvlc_media_player_t_ptr): Single; cdecl;

{*******************************************************************************
end bug
 *******************************************************************************}

{How many video outputs does this media player have?
param p_mi the media player
return the number of video outputs}
function libvlc_media_player_has_vout(p_mi: libvlc_media_player_t_ptr): LongWord; cdecl;

{Is this media player seekable?
param p_mi the media player
return true if the media player can seek}
function libvlc_media_player_is_seekable(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Can this media player be paused?
param p_mi the media player
return true if the media player can pause}
function libvlc_media_player_can_pause(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Display the next frame (if supported)
param p_mi the media player}
procedure libvlc_media_player_next_frame(p_mi: libvlc_media_player_t_ptr); cdecl;

{Release (free) libvlc_track_description_t
param p_track_description the structure to release}
procedure libvlc_track_description_release(p_track_description: libvlc_track_description_t_ptr); cdecl;

{Toggle fullscreen status on non-embedded video outputs.
warning The same limitations applies to this function
as to libvlc_set_fullscreen().
param p_mi the media player}
procedure libvlc_toggle_fullscreen(p_mi: libvlc_media_player_t_ptr); cdecl;

{Enable or disable fullscreen.
warning With most window managers, only a top-level windows can be in
full-screen mode. Hence, this function will not operate properly if
libvlc_media_player_set_xwindow() was used to embed the video in a
non-top-level window. In that case, the embedding window must be reparented
to the root window <b>before</b> fullscreen mode is enabled. You will want
to reparent it back to its normal parent when disabling fullscreen.
param p_mi the media player
param b_fullscreen boolean for fullscreen status}
procedure libvlc_set_fullscreen(p_mi: libvlc_media_player_t_ptr; b_fullscreen: Integer); cdecl;

{Get current fullscreen status.
param p_mi the media player
return the fullscreen status (boolean)}
function libvlc_get_fullscreen(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Enable or disable key press events handling, according to the LibVLC hotkeys
configuration. By default and for historical reasons, keyboard events are
handled by the LibVLC video widget.
On X11, there can be only one subscriber for key press and mouse
click events per window. If your application has subscribed to those events
for the X window ID of the video widget, then LibVLC will not be able to
handle key presses and mouse clicks in any case.
This function is only implemented for X11 at the moment.
param p_mi the media player
param on true to handle key press events, false to ignore them.}
procedure libvlc_video_set_key_input(p_mi: libvlc_media_player_t_ptr; keys_on: LongWord); cdecl;

{Enable or disable mouse click events handling. By default, those events are
handled. This is needed for DVD menus to work, as well as a few video
filters such as "puzzle".
See also libvlc_video_set_key_input().
This function is only implemented for X11 at the moment.
param p_mi the media player
param on true to handle mouse click events, false to ignore them.}
procedure libvlc_video_set_mouse_input(p_mi: libvlc_media_player_t_ptr; mouse_on: LongWord); cdecl;

{Get the pixel dimensions of a video.
param p_mi media player
param num number of the video (starting from, and most commonly 0)
param px pointer to get the pixel width [OUT]
param py pointer to get the pixel height [OUT]
return 0 on success, -1 if the specified video does not exist}
function libvlc_video_get_size(p_mi: libvlc_media_player_t_ptr; num:  LongWord; var px, py: LongWord): Integer; cdecl;

{$IFDEF USE_VLC_DEPRECATED_API}
{Get current video height.
You should use libvlc_video_get_size() instead.
param p_mi the media player
return the video pixel height or 0 if not applicable}
function libvlc_video_get_height(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;
{$ENDIF}

{$IFDEF USE_VLC_DEPRECATED_API}
{Get current video width.
You should use libvlc_video_get_size() instead.
param p_mi the media player
return the video pixel width or 0 if not applicable}
function libvlc_video_get_width(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;
{$ENDIF}

{Get the mouse pointer coordinates over a video.
Coordinates are expressed in terms of the decoded video resolution,
<b>not</b> in terms of pixels on the screen/viewport (to get the latter,
you can query your windowing system directly).
Either of the coordinates may be negative or larger than the corresponding
dimension of the video, if the cursor is outside the rendering area.
warning The coordinates may be out-of-date if the pointer is not located
on the video rendering area. LibVLC does not track the pointer if it is
outside of the video widget.
note LibVLC does not support multiple pointers (it does of course support
multiple input devices sharing the same pointer) at the moment.
param p_mi media player
param num number of the video (starting from, and most commonly 0)
param px pointer to get the abscissa [OUT]
param py pointer to get the ordinate [OUT]
return 0 on success, -1 if the specified video does not exist}
function libvlc_video_get_cursor(p_mi: libvlc_media_player_t_ptr; num:  LongWord; var px, py: Integer): Integer; cdecl;

{Get the current video scaling factor.
See also libvlc_video_set_scale().
param p_mi the media player
return the currently configured zoom factor, or 0. if the video is set
to fit to the output window/drawable automatically.}
function libvlc_video_get_scale(p_mi: libvlc_media_player_t_ptr): Single; cdecl;

{Set the video scaling factor. That is the ratio of the number of pixels on
screen to the number of pixels in the original decoded video in each
dimension. Zero is a special value; it will adjust the video to the output
window/drawable (in windowed mode) or the entire screen.
Note that not all video outputs support scaling.
param p_mi the media player
param f_factor the scaling factor, or zero}
procedure libvlc_video_set_scale(p_mi: libvlc_media_player_t_ptr; f_factor: Single); cdecl;

{Get current video aspect ratio.
param p_mi the media player
return the video aspect ratio or NULL if unspecified
(the result must be released with free()).}
function libvlc_video_get_aspect_ratio(p_mi: libvlc_media_player_t_ptr): PAnsiChar; cdecl;

{Set new video aspect ratio.
param p_mi the media player
param psz_aspect new video aspect-ratio or NULL to reset to default
Invalid aspect ratios are ignored.}
procedure libvlc_video_set_aspect_ratio(p_mi: libvlc_media_player_t_ptr; psz_aspect: PAnsiChar); cdecl;

{Get current video subtitle.
param p_mi the media player
return the video subtitle selected, or -1 if none}
function libvlc_video_get_spu(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Get the number of available video subtitles.
param p_mi the media player
return the number of available video subtitles}
function libvlc_video_get_spu_count(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Get the description of available video subtitles.
param p_mi the media player
return list containing description of available video subtitles}
function libvlc_video_get_spu_description(p_mi: libvlc_media_player_t_ptr): libvlc_track_description_t_ptr; cdecl;

{Set new video subtitle.
param p_mi the media player
param i_spu new video subtitle to select
return 0 on success, -1 if out of range}
function libvlc_video_set_spu(p_mi: libvlc_media_player_t_ptr; i_spu: LongWord): Integer; cdecl;

{Set new video subtitle file.
param p_mi the media player
param psz_subtitle new video subtitle file
return the success status (boolean)}
function libvlc_video_set_subtitle_file(p_mi: libvlc_media_player_t_ptr; psz_subtitle: PAnsiChar): Integer; cdecl;

{Get the description of available titles.
param p_mi the media player
return list containing description of available titles}
function libvlc_video_get_title_description(p_mi: libvlc_media_player_t_ptr): libvlc_track_description_t_ptr; cdecl;

{Get the description of available chapters for specific title.
param p_mi the media player
param i_title selected title
return list containing description of available chapter for title i_title}
function libvlc_video_get_chapter_description(p_mi: libvlc_media_player_t_ptr; i_title: Integer): libvlc_track_description_t_ptr; cdecl;

{Get current crop filter geometry.
param p_mi the media player
return the crop filter geometry or NULL if unset}
function libvlc_video_get_crop_geometry(p_mi: libvlc_media_player_t_ptr): PAnsiChar; cdecl;

{Set new crop filter geometry.
param p_mi the media player
param psz_geometry new crop filter geometry (NULL to unset)}
procedure libvlc_video_set_crop_geometry(p_mi: libvlc_media_player_t_ptr; psz_geometry: PAnsiChar); cdecl;

{Get current teletext page requested.
param p_mi the media player
return the current teletext page requested.}
function libvlc_video_get_teletext(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Set new teletext page to retrieve.
param p_mi the media player
param i_page teletex page number requested}
procedure libvlc_video_set_teletext(p_mi: libvlc_media_player_t_ptr; i_page: Integer); cdecl;

{Toggle teletext transparent status on video output.
param p_mi the media player}
procedure libvlc_toggle_teletext(p_mi: libvlc_media_player_t_ptr); cdecl;

{Get number of available video tracks.
param p_mi media player
return the number of available video tracks (int)}
function libvlc_video_get_track_count(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Get the description of available video tracks.
param p_mi media player
return list with description of available video tracks, or NULL on error}
function libvlc_video_get_track_description(p_mi: libvlc_media_player_t_ptr): libvlc_track_description_t_ptr; cdecl;

{Get current video track.
param p_mi media player
return the video track (int) or -1 if none}
function libvlc_video_get_track(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Set video track.
param p_mi media player
param i_track the track (int)
return 0 on success, -1 if out of range}
function libvlc_video_set_track(p_mi: libvlc_media_player_t_ptr; i_track: Integer): Integer; cdecl;

{Take a snapshot of the current video window.
If i_width AND i_height is 0, original size is used.
If i_width XOR i_height is 0, original aspect-ratio is preserved.
param p_mi media player instance
param num number of video output (typically 0 for the first/only one)
param psz_filepath the path where to save the screenshot to
param i_width the snapshot's width
param i_height the snapshot's height
return 0 on success, -1 if the video was not found}
function libvlc_video_take_snapshot(p_mi: libvlc_media_player_t_ptr; num: Integer; psz_filepath: PAnsiChar; i_width: LongWord; i_height: LongWord): Integer; cdecl;

{Enable or disable deinterlace filter
param p_mi libvlc media player
param psz_mode type of deinterlace filter, NULL to disable}
procedure libvlc_video_set_deinterlace(p_mi: libvlc_media_player_t_ptr; psz_mode: PAnsiChar); cdecl;

{Get an integer marquee option value
param p_mi libvlc media player
param option marq option to get \see libvlc_video_marquee_int_option_t}
function libvlc_video_get_marquee_int(p_mi: libvlc_media_player_t_ptr; option: libvlc_video_marquee_option_t): Integer; cdecl;

{Get a string marquee option value
param p_mi libvlc media player
param option marq option to get}
function libvlc_video_get_marquee_string(p_mi: libvlc_media_player_t_ptr; option: libvlc_video_marquee_option_t): PAnsiChar; cdecl;

{Enable, disable or set an integer marquee option
Setting libvlc_marquee_Enable has the side effect of enabling (arg !0)
or disabling (arg 0) the marq filter.
param p_mi libvlc media player
param option marq option to set
param i_val marq option value}
procedure libvlc_video_set_marquee_int(p_mi: libvlc_media_player_t_ptr; option: libvlc_video_marquee_option_t; i_val: Integer); cdecl;

{Set a marquee string option
param p_mi libvlc media player
param option marq option to set \see libvlc_video_marquee_string_option_t
param psz_text marq option value}
procedure libvlc_video_set_marquee_string(p_mi: libvlc_media_player_t_ptr; option: libvlc_video_marquee_option_t; psz_text: PAnsiChar); cdecl;

{Get integer logo option.
param p_mi libvlc media player instance
param option logo option to get, values of libvlc_video_logo_option_t}
function libvlc_video_get_logo_int(p_mi: libvlc_media_player_t_ptr; option: LongWord): Integer; cdecl;

{Set logo option as integer. Options that take a different type value
are ignored.
Passing libvlc_logo_enable as option value has the side effect of
starting (arg !0) or stopping (arg 0) the logo filter.
param p_mi libvlc media player instance
param option logo option to set, values of libvlc_video_logo_option_t
param value logo option value}
procedure libvlc_video_set_logo_int(p_mi: libvlc_media_player_t_ptr; option: LongWord; value: Integer); cdecl;

{Set logo option as string. Options that take a different type value
are ignored.
param p_mi libvlc media player instance
param option logo option to set, values of libvlc_video_logo_option_t
param psz_value logo option value}
procedure libvlc_video_set_logo_string(p_mi: libvlc_media_player_t_ptr; option: LongWord; psz_value: PAnsiChar); cdecl;

type
  libvlc_video_adjust_option_t = (
    libvlc_adjust_Enable = 0,
    libvlc_adjust_Contrast,
    libvlc_adjust_Brightness,
    libvlc_adjust_Hue,
    libvlc_adjust_Saturation,
    libvlc_adjust_Gamma
  );

{Get integer adjust option.
param p_mi libvlc media player instance
param option adjust option to get, values of libvlc_video_adjust_option_t
version LibVLC 1.1.1 and later.}
function libvlc_video_get_adjust_int(p_mi: libvlc_media_player_t_ptr; option: LongWord): Integer; cdecl;

{Set adjust option as integer. Options that take a different type value
are ignored.
Passing libvlc_adjust_enable as option value has the side effect of
starting (arg !0) or stopping (arg 0) the adjust filter.
param p_mi libvlc media player instance
param option adust option to set, values of libvlc_video_adjust_option_t
param value adjust option value
version LibVLC 1.1.1 and later.}
procedure libvlc_video_set_adjust_int(p_mi: libvlc_media_player_t_ptr; option: LongWord; value: Integer); cdecl;

{Get float adjust option.
\param p_mi libvlc media player instance
\param option adjust option to get, values of libvlc_video_adjust_option_t
\version LibVLC 1.1.1 and later.}
function libvlc_video_get_adjust_float(p_mi: libvlc_media_player_t_ptr; option: LongWord): Single; cdecl;

{Set adjust option as float. Options that take a different type value
are ignored.
param p_mi libvlc media player instance
param option adust option to set, values of libvlc_video_adjust_option_t
param value adjust option value
version LibVLC 1.1.1 and later.}
procedure libvlc_video_set_adjust_float(p_mi: libvlc_media_player_t_ptr; option: LongWord; value: Single); cdecl;

{Get the list of available audio outputs
param p_libvlc_instance libvlc instance
return list of available audio outputs. It must be freed it with
         see libvlc_audio_output_list_release see libvlc_audio_output_t .
        In case of error, NULL is returned.}
function libvlc_audio_output_list_get(p_libvlc_instance: libvlc_instance_t_ptr): libvlc_audio_output_t_ptr; cdecl;

{Free the list of available audio outputs
param p_list list with audio outputs for release}
procedure libvlc_audio_output_list_release(p_list: libvlc_audio_output_t_ptr); cdecl;

{Set the audio output.
Change will be applied after stop and play.
param p_mi media player
param psz_name name of audio output, use psz_name of \see libvlc_audio_output_t
return true if function succeded}
function libvlc_audio_output_set(p_mi: libvlc_media_player_t_ptr; psz_name: PAnsiChar): Integer; cdecl;

{Get count of devices for audio output, these devices are hardware oriented
like analor or digital output of sound card
param p_libvlc_instance libvlc instance
param psz_audio_output - name of audio output, \see libvlc_audio_output_t
return number of devices}
function libvlc_audio_output_device_count(p_libvlc_instance: libvlc_instance_t_ptr; psz_audio_output: PAnsiChar): Integer; cdecl;

{Get long name of device, if not available short name given
param p_libvlc_instance libvlc instance
param psz_audio_output - name of audio output, \see libvlc_audio_output_t
param i_device device index
return long name of device}
function libvlc_audio_output_device_longname(p_libvlc_instance: libvlc_instance_t_ptr; psz_audio_output: PAnsiChar; i_device: Integer): PAnsiChar; cdecl;

{Get id name of device
param p_libvlc_instance libvlc instance
param psz_audio_output - name of audio output, \see libvlc_audio_output_t
param i_device device index
return id name of device, use for setting device, need to be free after use}
function libvlc_audio_output_device_id(p_libvlc_instance: libvlc_instance_t_ptr; psz_audio_output: PAnsiChar; i_device: Integer): PAnsiChar; cdecl;

{Set audio output device. Changes are only effective after stop and play.
param p_mi media player
param psz_audio_output - name of audio output, see libvlc_audio_output_t
param psz_device_id device}
procedure libvlc_audio_output_device_set(p_mi: libvlc_media_player_t_ptr; psz_audio_output: PAnsiChar; psz_device_id: PAnsiChar); cdecl;

{Get current audio device type. Device type describes something like
character of output sound - stereo sound, 2.1, 5.1 etc
param p_mi media player
return the audio devices type see libvlc_audio_output_device_types_t}
function libvlc_audio_output_get_device_type(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Set current audio device type.
param p_mi vlc instance
param device_type the audio device type,
          according to see libvlc_audio_output_device_types_t}
procedure libvlc_audio_output_set_device_type(p_mi: libvlc_media_player_t_ptr; device_type: Integer); cdecl;

{Toggle mute status.
param p_mi media player}
procedure libvlc_audio_toggle_mute(p_mi: libvlc_media_player_t_ptr); cdecl;

{Get current mute status.
param p_mi media player
return the mute status (boolean)}
function libvlc_audio_get_mute(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Set mute status.
param p_mi media player
param status If status is true then mute, otherwise unmute}
procedure libvlc_audio_set_mute(p_mi: libvlc_media_player_t_ptr; status: Integer); cdecl;

{Get current audio level.
param p_mi media player
return the audio level (int)}
function libvlc_audio_get_volume(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Set current audio level.
param p_mi media player
param i_volume the volume (int)
return 0 if the volume was set, -1 if it was out of range}
function libvlc_audio_set_volume(p_mi: libvlc_media_player_t_ptr; i_volume: Integer): Integer; cdecl;

{Get number of available audio tracks.
param p_mi media player
return the number of available audio tracks (int), or -1 if unavailable}
function libvlc_audio_get_track_count(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Get the description of available audio tracks.
param p_mi media player
return list with description of available audio tracks, or NULL}
function libvlc_audio_get_track_description(p_mi: libvlc_media_player_t_ptr): libvlc_track_description_t_ptr; cdecl;

{Get current audio track.
param p_mi media player
return the audio track (int), or -1 if none.}
function libvlc_audio_get_track(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Set current audio track.
param p_mi media player
param i_track the track (int)
return 0 on success, -1 on error}
function libvlc_audio_set_track(p_mi: libvlc_media_player_t_ptr; i_track: Integer): Integer; cdecl;

{Get current audio channel.
param p_mi media player
return the audio channel \see libvlc_audio_output_channel_t}
function libvlc_audio_get_channel(p_mi: libvlc_media_player_t_ptr): Integer; cdecl;

{Set current audio channel.
param p_mi media player
param channel the audio channel, \see libvlc_audio_output_channel_t
return 0 on success, -1 on error}
function libvlc_audio_set_channel(p_mi: libvlc_media_player_t_ptr; i_channel: Integer): Integer; cdecl;

{Get current audio delay.
param p_mi media player
return the audio delay (microseconds)
version LibVLC 1.1.1 or later}
function libvlc_audio_get_delay(p_mi: libvlc_media_player_t_ptr): Int64; cdecl;

{Set current audio delay. The audio delay will be reset to zero each time the media changes.
param p_mi media player
param i_delay the audio delay (microseconds)
return 0 on success, -1 on error
version LibVLC 1.1.1 or later}
function libvlc_audio_set_delay(p_mi: libvlc_media_player_t_ptr; i_delay: Int64): Integer; cdecl;

{*******************************************************************************
libvlc_media_list.h
 *******************************************************************************}

{Create an empty media list.
param p_libvlc_instance libvlc instance
return empty media list, or NULL on error}
function libvlc_media_list_new(p_libvlc_instance: libvlc_instance_t_ptr): libvlc_media_list_t_ptr; cdecl;

{Release media list created with libvlc_media_list_new().
param p_ml a media list created with libvlc_media_list_new()}
procedure libvlc_media_list_release(p_ml: libvlc_media_list_t_ptr); cdecl;

{Retain reference to a media list
param p_ml a media list created with libvlc_media_list_new()}
procedure libvlc_media_list_retain(p_ml: libvlc_media_list_t_ptr); cdecl;

{$IFDEF USE_VLC_DEPRECATED_API}
function libvlc_media_list_add_file_content(p_ml: libvlc_media_list_t_ptr; psz_uri: PAnsiChar): Integer; cdecl;
{$ENDIF}

{Associate media instance with this media list instance.
If another media instance was present it will be released.
The libvlc_media_list_lock should NOT be held upon entering this function.
param p_ml a media list instance
param p_md media instance to add}
procedure libvlc_media_list_set_media(p_ml: libvlc_media_list_t_ptr; p_md: libvlc_media_t_ptr); cdecl;

{Get media instance from this media list instance. This action will increase
the refcount on the media instance.
The libvlc_media_list_lock should NOT be held upon entering this function.
param p_ml a media list instance
return media instance}
function libvlc_media_list_media(p_ml: libvlc_media_list_t_ptr): libvlc_media_t_ptr; cdecl;

{Add media instance to media list
The libvlc_media_list_lock should be held upon entering this function.
param p_ml a media list instance
param p_md a media instance
return 0 on success, -1 if the media list is read-only}
function libvlc_media_list_add_media(p_ml: libvlc_media_list_t_ptr; p_md: libvlc_media_t_ptr): Integer; cdecl;

{Insert media instance in media list on a position
The libvlc_media_list_lock should be held upon entering this function.
param p_ml a media list instance
param p_md a media instance
param i_pos position in array where to insert
return 0 on success, -1 if the media list si read-only}
function libvlc_media_list_insert_media(p_ml: libvlc_media_list_t_ptr; p_md: libvlc_media_t_ptr; i_pos: Integer): Integer; cdecl;

{Remove media instance from media list on a position
The libvlc_media_list_lock should be held upon entering this function.
param p_ml a media list instance
param i_pos position in array where to insert
return 0 on success, -1 if the list is read-only or the item was not found}
function libvlc_media_list_remove_index(p_ml: libvlc_media_list_t_ptr; i_pos: Integer): Integer; cdecl;

{Get count on media list items
The libvlc_media_list_lock should be held upon entering this function.
param p_ml a media list instance
return number of items in media list}
function libvlc_media_list_count(p_ml: libvlc_media_list_t_ptr): Integer; cdecl;

{List media instance in media list at a position
The libvlc_media_list_lock should be held upon entering this function.
param p_ml a media list instance
param i_pos position in array where to insert
return media instance at position i_pos, or NULL if not found.
In case of success, libvlc_media_retain() is called to increase the refcount
on the media.}
function libvlc_media_list_item_at_index(p_ml: libvlc_media_list_t_ptr; i_pos: Integer): libvlc_media_t_ptr; cdecl;

{Find index position of List media instance in media list.
Warning: the function will return the first matched position.
The libvlc_media_list_lock should be held upon entering this function.
param p_ml a media list instance
param p_md media list instance
return position of media instance}
function libvlc_media_list_index_of_item(p_ml: libvlc_media_list_t_ptr; p_md: libvlc_media_t_ptr): Integer; cdecl;

{This indicates if this media list is read-only from a user point of view
param p_ml media list instance
return 0 on readonly, 1 on readwrite}
function libvlc_media_list_is_readonly(p_ml: libvlc_media_list_t_ptr): Integer; cdecl;

{Get lock on media list items
param p_ml a media list instance}
procedure libvlc_media_list_lock(p_ml: libvlc_media_list_t_ptr); cdecl;

{Release lock on media list items
The libvlc_media_list_lock should be held upon entering this function.
param p_ml a media list instance}
procedure libvlc_media_list_unlock(p_ml: libvlc_media_list_t_ptr); cdecl;

{Get libvlc_event_manager from this media list instance.
The p_event_manager is immutable, so you don't have to hold the lock
param p_ml a media list instance
return libvlc_event_manager}
function libvlc_media_list_event_manager(p_ml: libvlc_media_list_t_ptr): libvlc_event_manager_t_ptr; cdecl;

{*****************************************************************************
libvlc_media_list_player.h
 *******************************************************************************}

{The LibVLC media list player plays a ref libvlc_media_list_t list of media,
in a certain order.
This is required to especially support playlist files.
The normal ref libvlc_media_player_t LibVLC media player can only play a
single media, and does not handle playlist files properly.}

{Create new media_list_player.
param p_libvlc_instance libvlc instance
return media list player instance or NULL on error}
function libvlc_media_list_player_new(p_libvlc_instance: libvlc_instance_t_ptr): libvlc_media_list_player_t_ptr; cdecl;

{Release media_list_player.
param p_mlp media list player instance}
procedure libvlc_media_list_player_release(p_mlp: libvlc_media_list_player_t_ptr); cdecl;

{Return the event manager of this media_list_player.
param p_mlp media list player instance
return the event manager}
function libvlc_media_list_player_event_manager(p_mlp: libvlc_media_list_player_t_ptr): libvlc_event_manager_t_ptr; cdecl;

{Replace media player in media_list_player with this instance.
param p_mlp media list player instance
param p_mi media player instance}
procedure libvlc_media_list_player_set_media_player(p_mlp: libvlc_media_list_player_t_ptr; p_mi: libvlc_media_player_t_ptr); cdecl;

{Set the media list associated with the player
param p_mlp media list player instance
param p_mlist list of media}
procedure libvlc_media_list_player_set_media_list(p_mlp: libvlc_media_list_player_t_ptr; p_mlist: libvlc_media_list_t_ptr); cdecl;

{Play media list
param p_mlp media list player instance}
procedure libvlc_media_list_player_play(p_mlp: libvlc_media_list_player_t_ptr); cdecl;

{Pause media list
param p_mlp media list player instance}
procedure libvlc_media_list_player_pause(p_mlp: libvlc_media_list_player_t_ptr); cdecl;

{Is media list playing?
param p_mlp media list player instance
return true for playing and false for not playing}
function libvlc_media_list_player_is_playing(p_mlp: libvlc_media_list_player_t_ptr): Integer; cdecl;

{Get current libvlc_state of media list player
param p_mlp media list player instance
return libvlc_state_t for media list player}
function libvlc_media_list_player_get_state(p_mlp: libvlc_media_list_player_t_ptr): libvlc_state_t; cdecl;

{Play media list item at position index
param p_mlp media list player instance
param i_index index in media list to play
return 0 upon success -1 if the item wasn't found}
function libvlc_media_list_player_play_item_at_index(p_mlp: libvlc_media_list_player_t_ptr; i_index: Integer): Integer; cdecl;

{Play the given media item
param p_mlp media list player instance
param p_md the media instance
return 0 upon success, -1 if the media is not part of the media list}
function libvlc_media_list_player_play_item(p_mlp: libvlc_media_list_player_t_ptr; p_md: libvlc_media_t_ptr): Integer; cdecl;

{Stop playing media list
param p_mlp media list player instance}
procedure libvlc_media_list_player_stop(p_mlp: libvlc_media_list_player_t_ptr); cdecl;

{Play next item from media list
param p_mlp media list player instance
return 0 upon success -1 if there is no next item}
function libvlc_media_list_player_next(p_mlp: libvlc_media_list_player_t_ptr): Integer; cdecl;

{Play previous item from media list
param p_mlp media list player instance
return 0 upon success -1 if there is no previous item}
function libvlc_media_list_player_previous(p_mlp: libvlc_media_list_player_t_ptr): Integer; cdecl;

{Sets the playback mode for the playlist
param p_mlp media list player instance
param e_mode playback mode specification}
procedure libvlc_media_list_player_set_playback_mode(p_mlp: libvlc_media_list_player_t_ptr; e_mode: libvlc_playback_mode_t); cdecl;

{*******************************************************************************
libvlc_media_library.h
 *******************************************************************************}

{Create an new Media Library object
param p_libvlc_instance the libvlc instance
return a new object or NULL on error}
function libvlc_media_library_new(): libvlc_media_library_t_ptr; cdecl;

{Release media library object. This functions decrements the
reference count of the media library object. If it reaches 0,
then the object will be released.
param p_mlib media library object}
procedure libvlc_media_library_release(p_mlib: libvlc_media_library_t_ptr); cdecl;

{Retain a reference to a media library object. This function will
increment the reference counting for this object. Use
libvlc_media_library_release() to decrement the reference count.
param p_mlib media library object}
procedure libvlc_media_library_retain(p_mlib: libvlc_media_library_t_ptr); cdecl;

{Load media library.
param p_mlib media library object
return 0 on success, -1 on error}
function libvlc_media_library_load(p_mlib: libvlc_media_library_t_ptr): Integer; cdecl;

{Get media library subitems.
param p_mlib media library object
return media list subitems}
function libvlc_media_library_media_list(p_mlib: libvlc_media_library_t_ptr): libvlc_media_list_t_ptr; cdecl;

{*****************************************************************************
libvlc_media_discoverer.h
 *******************************************************************************}

{LibVLC media discovery finds available media via various means.
This corresponds to the service discovery functionality in VLC media player.
Different plugins find potential medias locally (e.g. user media directory),
from peripherals (e.g. video capture device), on the local network
(e.g. SAP) or on the Internet (e.g. Internet radios).}

{Discover media service by name.
param p_inst libvlc instance
param psz_name service name
return media discover object or NULL in case of error}
function libvlc_media_discoverer_new_from_name(p_inst: libvlc_instance_t_ptr; psz_name: PAnsiChar): libvlc_media_discoverer_t_ptr; cdecl;

{Release media discover object. If the reference count reaches 0, then
the object will be released.
param p_mdis media service discover object}
procedure libvlc_media_discoverer_release(p_mdis: libvlc_media_discoverer_t_ptr); cdecl;

{Get media service discover object its localized name.
param p_mdis media discover object
return localized name}
function libvlc_media_discoverer_localized_name(p_mdis: libvlc_media_discoverer_t_ptr): PAnsiChar; cdecl;

{Get media service discover media list.
param p_mdis media service discover object
return list of media items}
function libvlc_media_discoverer_media_list(p_mdis: libvlc_media_discoverer_t_ptr): libvlc_media_list_t_ptr; cdecl;

{Get event manager from media service discover object.
param p_mdis media service discover object
return event manager object.}
function libvlc_media_discoverer_event_manager(p_mdis: libvlc_media_discoverer_t_ptr): libvlc_event_manager_t_ptr; cdecl;

{Query if media service discover object is running.
param p_mdis media service discover object
return true if running, false if not}

function libvlc_media_discoverer_is_running(p_mdis: libvlc_media_discoverer_t_ptr): Integer; cdecl;

{*******************************************************************************
libvlc_vlm.h
 *******************************************************************************}

{Release the vlm instance related to the given libvlc_instance_t
param p_libvlc_instance the instance}
procedure libvlc_vlm_release(p_libvlc_instance: libvlc_instance_t_ptr); cdecl;

{Add a broadcast, with one input.
param p_libvlc_instance the instance
param psz_name the name of the new broadcast
param psz_input the input MRL
param psz_output the output MRL (the parameter to the "sout" variable)
param i_options number of additional options
param ppsz_options additional options
param b_enabled boolean for enabling the new broadcast
param b_loop Should this broadcast be played in loop ?
return 0 on success, -1 on error}
function libvlc_vlm_add_broadcast(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; psz_input: PAnsiChar;
  psz_output: PAnsiChar; i_options: Integer; ppsz_options: PPAnsiChar; b_enabled: Integer; b_loop: Integer ): Integer; cdecl;

{Add a vod, with one input.
param p_libvlc_instance the instance
param psz_name the name of the new vod media
param psz_input the input MRL
param i_options number of additional options
param ppsz_options additional options
param b_enabled boolean for enabling the new vod
param psz_mux the muxer of the vod media
return 0 on success, -1 on error}
function libvlc_vlm_add_vod(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; psz_input: PAnsiChar; i_options: Integer;
  ppsz_options: PPAnsiChar; b_enabled: Integer; psz_mux: PAnsiChar): Integer; cdecl;

{Delete a media (VOD or broadcast).
param p_libvlc_instance the instance
param psz_name the media to delete
return 0 on success, -1 on error}
function libvlc_vlm_del_media(p_libvlc_instance: libvlc_instance_t_ptr; psz_media_name: PAnsiChar): Integer; cdecl;

{Enable or disable a media (VOD or broadcast).
param p_libvlc_instance the instance
param psz_name the media to work on
param b_enabled the new status
return 0 on success, -1 on error}
function libvlc_vlm_set_enabled(p_libvlc_instance: libvlc_instance_t_ptr; psz_media_name: PAnsiChar; b_enabled: Integer): Integer; cdecl;

{Set the output for a media.
param p_libvlc_instance the instance
param psz_name the media to work on
param psz_output the output MRL (the parameter to the "sout" variable)
return 0 on success, -1 on error}
function libvlc_vlm_set_output(p_libvlc_instance: libvlc_instance_t_ptr; psz_media_name: PAnsiChar; psz_output: PAnsiChar): Integer; cdecl;

{Set a media's input MRL. This will delete all existing inputs and
add the specified one.
param p_libvlc_instance the instance
param psz_name the media to work on
param psz_input the input MRL
return 0 on success, -1 on error}
function libvlc_vlm_set_input(p_libvlc_instance: libvlc_instance_t_ptr; psz_media_name: PAnsiChar; psz_input: PAnsiChar): Integer; cdecl;

{Add a media's input MRL. This will add the specified one.
param p_libvlc_instance the instance
param psz_name the media to work on
param psz_input the input MRL
return 0 on success, -1 on error}
function libvlc_vlm_add_input(p_libvlc_instance: libvlc_instance_t_ptr; psz_media_name: PAnsiChar; psz_input: PAnsiChar): Integer; cdecl;

{Set a media's loop status.
param p_libvlc_instance the instance
param psz_name the media to work on
param b_loop the new status
return 0 on success, -1 on error}
function libvlc_vlm_set_loop(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; b_loop: Integer): Integer; cdecl;

{Set a media's vod muxer.
param p_libvlc_instance the instance
param psz_name the media to work on
param psz_mux the new muxer
return 0 on success, -1 on error}
function libvlc_vlm_set_mux(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; psz_mux: PAnsiChar): Integer; cdecl;

{Edit the parameters of a media. This will delete all existing inputs and
add the specified one.
param p_libvlc_instance the instance
param psz_name the name of the new broadcast
param psz_input the input MRL
param psz_output the output MRL (the parameter to the "sout" variable)
param i_options number of additional options
param ppsz_options additional options
param b_enabled boolean for enabling the new broadcast
param b_loop Should this broadcast be played in loop ?
return 0 on success, -1 on error}
function libvlc_vlm_change_media(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; psz_input: PAnsiChar; psz_output: PAnsiChar;
  i_options: Integer; ppsz_options: PPAnsiChar; b_enabled: Integer; b_loop: Integer): Integer; cdecl;

{Play the named broadcast.
param p_libvlc_instance the instance
param psz_name the name of the broadcast
return 0 on success, -1 on error}
function libvlc_vlm_play_media(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar): Integer; cdecl;

{Stop the named broadcast.
param p_libvlc_instance the instance
param psz_name the name of the broadcast
return 0 on success, -1 on error}
function libvlc_vlm_stop_media(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar): Integer; cdecl;

{Pause the named broadcast.
param p_libvlc_instance the instance
param psz_name the name of the broadcast
return 0 on success, -1 on error}
function libvlc_vlm_pause_media(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar): Integer; cdecl;

{Seek in the named broadcast.
param p_libvlc_instance the instance
param psz_name the name of the broadcast
param f_percentage the percentage to seek to
return 0 on success, -1 on error}
function libvlc_vlm_seek_media(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; f_percentage: Single): Integer; cdecl;

{Return information about the named media as a JSON
string representation.
This function is mainly intended for debugging use,
if you want programmatic access to the state of
a vlm_media_instance_t, please use the corresponding
libvlc_vlm_get_media_instance_xxx -functions.
Currently there are no such functions available for
vlm_media_t though.
param p_libvlc_instance the instance
param psz_name the name of the media,
     if the name is an empty string, all media is described
return string with information about named media, or NULL on error}
function libvlc_vlm_show_media(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar): PAnsiChar; cdecl;

{Get vlm_media instance position by name or instance id
param p_libvlc_instance a libvlc instance
param psz_name name of vlm media instance
param i_instance instance id
return position as float or -1. on error}
function libvlc_vlm_get_media_instance_position(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; i_instance: Integer): Single; cdecl;

{Get vlm_media instance time by name or instance id
param p_libvlc_instance a libvlc instance
param psz_name name of vlm media instance
param i_instance instance id
return time as integer or -1 on error}
function libvlc_vlm_get_media_instance_time(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; i_instance: Integer): Integer; cdecl;

{Get vlm_media instance length by name or instance id
param p_libvlc_instance a libvlc instance
param psz_name name of vlm media instance
param i_instance instance id
return length of media item or -1 on error}
function libvlc_vlm_get_media_instance_length(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; i_instance: Integer): Integer; cdecl;

{Get vlm_media instance playback rate by name or instance id
param p_libvlc_instance a libvlc instance
param psz_name name of vlm media instance
param i_instance instance id
return playback rate or -1 on error}
function libvlc_vlm_get_media_instance_rate(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; i_instance: Integer): Integer; cdecl;

{Get libvlc_event_manager from a vlm media.
The p_event_manager is immutable, so you don't have to hold the lock
param p_libvlc_instance a libvlc instance
return libvlc_event_manager}
function libvlc_vlm_get_event_manager(p_libvlc_instance: libvlc_instance_t_ptr): libvlc_event_manager_t_ptr; cdecl;

{*******************************************************************************
decpecated.h
 *******************************************************************************}

{$IFDEF USE_VLC_DEPRECATED_API}
{Start playing (if there is any item in the playlist).
Additionnal playlist item options can be specified for addition to the
item before it is played.
param p_libvlc_instance the playlist instance
param i_id the item to play. If this is a negative number, the next
      item will be selected. Otherwise, the item with the given ID will be
      played
param i_options the number of options to add to the item
param ppsz_options the options to add to the item}
procedure libvlc_playlist_play(p_libvlc_instance: libvlc_instance_t_ptr; i_id: Integer; i_options: Integer; ppsz_options: PPAnsiChar); cdecl;
{$ENDIF}


implementation // ***************************************************************************************************************



//procedure libvlc_event_callback_t(p_event: libvlc_event_t_ptr; data:  Pointer); cdecl; external;
function libvlc_errmsg(): PAnsiChar; cdecl; external;
procedure libvlc_clearerr(); cdecl; external;
function libvlc_vprinterr(fmt: PAnsiChar; ap: array of pointer): PAnsiChar; cdecl; external;
function libvlc_printerr(fmt: PAnsiChar): PAnsiChar; cdecl; external;
function libvlc_new(argc: Integer; args: PPAnsiChar): libvlc_instance_t_ptr; cdecl; external;
procedure libvlc_release(p_libvlc_instance: libvlc_instance_t_ptr); cdecl; external;
procedure libvlc_retain(p_libvlc_instance: libvlc_instance_t_ptr); cdecl; external;
function libvlc_add_intf(p_libvlc_instance: libvlc_instance_t_ptr; name: PAnsiChar): Integer; cdecl; external;
procedure libvlc_wait(p_libvlc_instance: libvlc_instance_t_ptr); cdecl; external;
procedure libvlc_set_user_agent(p_libvlc_instance: libvlc_instance_t_ptr;name: PAnsiChar;http: PAnsiChar); cdecl; external;
function libvlc_get_version(): PAnsiChar; cdecl; external;
function libvlc_get_compiler(): PAnsiChar; cdecl; external;
function libvlc_get_changeset(): PAnsiChar; cdecl; external;
function libvlc_event_attach(p_event_manager: libvlc_event_manager_t_ptr; i_event_type: libvlc_event_type_t; f_callback: libvlc_event_callback_t; user_data:Pointer): Integer; cdecl; external;
procedure libvlc_event_detach(p_event_manager: libvlc_event_manager_t_ptr; i_event_type:    libvlc_event_type_t; f_callback: libvlc_event_callback_t; p_user_data: Pointer); cdecl; external;
function libvlc_event_type_name(event_type: libvlc_event_type_t): PAnsiChar; cdecl; external;
function libvlc_get_log_verbosity(p_libvlc_instance: libvlc_instance_t_ptr): LongWord; cdecl; external;
procedure libvlc_set_log_verbosity(p_libvlc_instance: libvlc_instance_t_ptr; level: LongWord); cdecl; external;
function libvlc_log_open(p_libvlc_instance: libvlc_instance_t_ptr): libvlc_log_t_ptr; cdecl; external;
procedure libvlc_log_close(p_log: libvlc_log_t_ptr); cdecl; external;
function libvlc_log_count(p_log: libvlc_log_t_ptr): LongWord; cdecl; external;
procedure libvlc_log_clear(p_log: libvlc_log_t_ptr); cdecl; external;
function libvlc_log_get_iterator(p_log: libvlc_log_t_ptr): libvlc_log_iterator_t_ptr; cdecl; external;
procedure libvlc_log_iterator_free(p_log: libvlc_log_t_ptr); cdecl; external;
function libvlc_log_iterator_has_next(p_iter: libvlc_log_iterator_t_ptr): LongInt; cdecl; external;
function libvlc_log_iterator_next(p_iter: libvlc_log_iterator_t_ptr; p_buffer: libvlc_log_message_t_ptr): libvlc_log_message_t_ptr; cdecl; external;
// libvlc_media.h
function libvlc_media_new_location(p_libvlc_instance: libvlc_instance_t_ptr; psz_mrl: PAnsiChar): libvlc_media_t_ptr; cdecl; external;
function libvlc_media_new_path(p_libvlc_instance: libvlc_instance_t_ptr; path: PAnsiChar): libvlc_media_t_ptr; cdecl; external;
function libvlc_media_new_as_node(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar): libvlc_media_t_ptr; cdecl; external;
procedure libvlc_media_add_option(p_md: libvlc_media_t_ptr; ppsz_options: PAnsiChar); cdecl; external;
procedure libvlc_media_add_option_flag(p_md: libvlc_media_t_ptr; ppsz_options: PAnsiChar;i_flags: LongWord); cdecl; external;
procedure libvlc_media_retain(p_md: libvlc_media_t_ptr); cdecl; external;
procedure libvlc_media_release(p_md: libvlc_media_t_ptr); cdecl; external;
function libvlc_media_get_mrl(p_md: libvlc_media_t_ptr): PAnsiChar; cdecl; external;
function libvlc_media_duplicate(p_md: libvlc_media_t_ptr): libvlc_media_t_ptr; cdecl; external;
function libvlc_media_get_meta(p_md:   libvlc_media_t_ptr; e_meta: libvlc_meta_t): PAnsiChar; cdecl; external;
procedure libvlc_media_set_meta(p_md: libvlc_media_t_ptr; e_meta: libvlc_meta_t; psz_value: PAnsiChar); cdecl; external;
function libvlc_media_save_meta(p_md: libvlc_media_t_ptr): Integer; cdecl; external;
function libvlc_media_get_state(p_meta_desc: libvlc_media_t_ptr): libvlc_state_t; cdecl; external;
function libvlc_media_get_stats(p_md: libvlc_media_t_ptr; p_stats: libvlc_media_stats_t_ptr): Integer; cdecl; external;
function libvlc_media_subitems(p_md: libvlc_media_t_ptr): libvlc_media_list_t_ptr; cdecl; external;
function libvlc_media_event_manager(p_md: libvlc_media_t_ptr): libvlc_event_manager_t_ptr; cdecl; external;
function libvlc_media_get_duration(p_md: libvlc_media_t_ptr): libvlc_time_t; cdecl; external;
procedure libvlc_media_parse(media: libvlc_media_t_ptr); cdecl; external;
procedure libvlc_media_parse_async(media: libvlc_media_t_ptr); cdecl; external;
function libvlc_media_is_parsed(p_md: libvlc_media_t_ptr): Integer; cdecl; external;
procedure libvlc_media_set_user_data(p_md: libvlc_media_t_ptr;p_new_user_data: Pointer); cdecl; external;
function libvlc_media_get_user_data(p_md: libvlc_media_t_ptr): Pointer; cdecl; external;
function libvlc_media_get_tracks_info(media: libvlc_media_t_ptr; var tracks: libvlc_media_track_info_t_ptr): Integer; cdecl; external;
// libvlc_media_player.h
function libvlc_media_player_new(p_libvlc_instance: libvlc_instance_t_ptr): libvlc_media_player_t_ptr; cdecl; external;
function libvlc_media_player_new_from_media(p_md: libvlc_media_t_ptr): libvlc_media_player_t_ptr; cdecl; external;
procedure libvlc_media_player_release(p_mi: libvlc_media_player_t_ptr); cdecl; external;
procedure libvlc_media_player_retain(p_mi: libvlc_media_player_t_ptr); cdecl; external;
procedure libvlc_media_player_set_media(p_mi: libvlc_media_player_t_ptr;p_md: libvlc_media_t_ptr); cdecl; external;
function libvlc_media_player_get_media(p_mi: libvlc_media_player_t_ptr): libvlc_media_t_ptr; cdecl; external;
function libvlc_media_player_event_manager(p_mi: libvlc_media_player_t_ptr): libvlc_event_manager_t_ptr; cdecl; external;
function libvlc_media_player_is_playing(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_media_player_play(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
procedure libvlc_media_player_set_pause(p_mi: libvlc_media_player_t_ptr; do_pause: Integer); cdecl; external;
procedure libvlc_media_player_pause(p_mi: libvlc_media_player_t_ptr); cdecl; external;
procedure libvlc_media_player_stop(p_mi: libvlc_media_player_t_ptr); cdecl; external;
procedure libvlc_video_set_callbacks(p_mi: libvlc_media_player_t_ptr; lock: lock_call_fun; unlock: unlock_call_fun; display: display_call_fun; opaque: Pointer); cdecl; external;
procedure libvlc_video_set_format(p_mi: libvlc_media_player_t_ptr; chroma: PAnsiChar; width: Longword; height: Longword; pitch: Longword); cdecl; external;
procedure libvlc_media_player_set_nsobject(p_mi: libvlc_media_player_t_ptr; drawable: Pointer); cdecl; external;
function libvlc_media_player_get_nsobject(p_mi: libvlc_media_player_t_ptr): Pointer; cdecl; external;
procedure libvlc_media_player_set_agl(p_mi: libvlc_media_player_t_ptr; drawable: LongWord); cdecl; external;
function libvlc_media_player_get_agl(p_mi: libvlc_media_player_t_ptr): LongWord; cdecl; external;
procedure libvlc_media_player_set_xwindow(p_mi: libvlc_media_player_t_ptr; drawable: LongWord); cdecl; external;
function libvlc_media_player_get_xwindow(p_mi: libvlc_media_player_t_ptr): LongWord; cdecl; external;
procedure libvlc_media_player_set_hwnd(p_mi: libvlc_media_player_t_ptr; hwnd: THandle); cdecl; external;
function libvlc_media_player_get_hwnd(p_mi: libvlc_media_player_t_ptr): THandle; cdecl; external;
function libvlc_media_player_get_length(p_mi: libvlc_media_player_t_ptr): libvlc_time_t; cdecl; external;
function libvlc_media_player_get_time(p_mi: libvlc_media_player_t_ptr): libvlc_time_t; cdecl; external;
procedure libvlc_media_player_set_time(p_mi: libvlc_media_player_t_ptr; i_time: libvlc_time_t); cdecl; external;
function libvlc_media_player_get_position(p_mi: libvlc_media_player_t_ptr): Single; cdecl; external;
procedure libvlc_media_player_set_position(p_mi:  libvlc_media_player_t_ptr; f_pos: Single); cdecl; external;
procedure libvlc_media_player_set_chapter(p_mi: libvlc_media_player_t_ptr; i_chapter: Integer); cdecl; external;
function libvlc_media_player_get_chapter(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_media_player_get_chapter_count(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_media_player_will_play(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_media_player_get_chapter_count_for_title(p_mi: libvlc_media_player_t_ptr; i_title: Integer): Integer; cdecl; external;
procedure libvlc_media_player_set_title(p_mi: libvlc_media_player_t_ptr; i_title: Integer); cdecl; external;
function libvlc_media_player_get_title(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_media_player_get_title_count(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
procedure libvlc_media_player_previous_chapter(p_mi: libvlc_media_player_t_ptr); cdecl; external;
procedure libvlc_media_player_next_chapter(p_mi: libvlc_media_player_t_ptr); cdecl; external;
function libvlc_media_player_get_rate(p_mi: libvlc_media_player_t_ptr): Single; cdecl; external;
function libvlc_media_player_set_rate(p_mi: libvlc_media_player_t_ptr; rate: Single): Integer; cdecl; external;
function libvlc_media_player_get_state(p_mi: libvlc_media_player_t_ptr): libvlc_state_t; cdecl; external;
function libvlc_media_player_get_fps(p_mi: libvlc_media_player_t_ptr): Single; cdecl; external;
function libvlc_media_player_has_vout(p_mi: libvlc_media_player_t_ptr): LongWord; cdecl; external;
function libvlc_media_player_is_seekable(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_media_player_can_pause(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
procedure libvlc_media_player_next_frame(p_mi: libvlc_media_player_t_ptr); cdecl; external;
procedure libvlc_track_description_release(p_track_description: libvlc_track_description_t_ptr); cdecl; external;
procedure libvlc_toggle_fullscreen(p_mi: libvlc_media_player_t_ptr); cdecl; external;
procedure libvlc_set_fullscreen(p_mi: libvlc_media_player_t_ptr; b_fullscreen: Integer); cdecl; external;
function libvlc_get_fullscreen(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
procedure libvlc_video_set_key_input(p_mi: libvlc_media_player_t_ptr; keys_on: LongWord); cdecl; external;
procedure libvlc_video_set_mouse_input(p_mi: libvlc_media_player_t_ptr; mouse_on: LongWord); cdecl; external;
function libvlc_video_get_size(p_mi: libvlc_media_player_t_ptr; num:  LongWord; var px, py: LongWord): Integer; cdecl; external;
{$IFDEF USE_VLC_DEPRECATED_API}
function libvlc_video_get_height(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_video_get_width(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
{$ENDIF}
function libvlc_video_get_cursor(p_mi: libvlc_media_player_t_ptr; num:  LongWord; var px, py: Integer): Integer; cdecl; external;
function libvlc_video_get_scale(p_mi: libvlc_media_player_t_ptr): Single; cdecl; external;
procedure libvlc_video_set_scale(p_mi: libvlc_media_player_t_ptr; f_factor: Single); cdecl; external;
function libvlc_video_get_aspect_ratio(p_mi: libvlc_media_player_t_ptr): PAnsiChar; cdecl; external;
procedure libvlc_video_set_aspect_ratio(p_mi: libvlc_media_player_t_ptr; psz_aspect: PAnsiChar); cdecl; external;
function libvlc_video_get_spu(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_video_get_spu_count(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_video_get_spu_description(p_mi: libvlc_media_player_t_ptr): libvlc_track_description_t_ptr; cdecl; external;
function libvlc_video_set_spu(p_mi: libvlc_media_player_t_ptr; i_spu: LongWord): Integer; cdecl; external;
function libvlc_video_set_subtitle_file(p_mi: libvlc_media_player_t_ptr; psz_subtitle: PAnsiChar): Integer; cdecl; external;
function libvlc_video_get_title_description(p_mi: libvlc_media_player_t_ptr): libvlc_track_description_t_ptr; cdecl; external;
function libvlc_video_get_chapter_description(p_mi: libvlc_media_player_t_ptr; i_title: Integer): libvlc_track_description_t_ptr; cdecl; external;
function libvlc_video_get_crop_geometry(p_mi: libvlc_media_player_t_ptr): PAnsiChar; cdecl; external;
procedure libvlc_video_set_crop_geometry(p_mi: libvlc_media_player_t_ptr; psz_geometry: PAnsiChar); cdecl; external;
function libvlc_video_get_teletext(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
procedure libvlc_video_set_teletext(p_mi: libvlc_media_player_t_ptr; i_page: Integer); cdecl; external;
procedure libvlc_toggle_teletext(p_mi: libvlc_media_player_t_ptr); cdecl; external;
function libvlc_video_get_track_count(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_video_get_track_description(p_mi: libvlc_media_player_t_ptr): libvlc_track_description_t_ptr; cdecl; external;
function libvlc_video_get_track(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_video_set_track(p_mi: libvlc_media_player_t_ptr; i_track: Integer): Integer; cdecl; external;
function libvlc_video_take_snapshot(p_mi: libvlc_media_player_t_ptr; num: Integer; psz_filepath: PAnsiChar; i_width: LongWord; i_height: LongWord): Integer; cdecl; external;
procedure libvlc_video_set_deinterlace(p_mi: libvlc_media_player_t_ptr; psz_mode: PAnsiChar); cdecl; external;
function libvlc_video_get_marquee_int(p_mi: libvlc_media_player_t_ptr; option: libvlc_video_marquee_option_t): Integer; cdecl; external;
function libvlc_video_get_marquee_string(p_mi: libvlc_media_player_t_ptr; option: libvlc_video_marquee_option_t): PAnsiChar; cdecl; external;
procedure libvlc_video_set_marquee_int(p_mi: libvlc_media_player_t_ptr; option: libvlc_video_marquee_option_t; i_val: Integer); cdecl; external;
procedure libvlc_video_set_marquee_string(p_mi: libvlc_media_player_t_ptr; option: libvlc_video_marquee_option_t; psz_text: PAnsiChar); cdecl; external;
function libvlc_video_get_logo_int(p_mi: libvlc_media_player_t_ptr; option: LongWord): Integer; cdecl; external;
procedure libvlc_video_set_logo_int(p_mi: libvlc_media_player_t_ptr; option: LongWord; value: Integer); cdecl; external;
procedure libvlc_video_set_logo_string(p_mi: libvlc_media_player_t_ptr; option: LongWord; psz_value: PAnsiChar); cdecl; external;
function libvlc_video_get_adjust_int(p_mi: libvlc_media_player_t_ptr; option: LongWord): Integer; cdecl; external;
procedure libvlc_video_set_adjust_int(p_mi: libvlc_media_player_t_ptr; option: LongWord; value: Integer); cdecl; external;
function libvlc_video_get_adjust_float(p_mi: libvlc_media_player_t_ptr; option: LongWord): Single; cdecl; external;
procedure libvlc_video_set_adjust_float(p_mi: libvlc_media_player_t_ptr; option: LongWord; value: Single); cdecl; external;
function libvlc_audio_output_list_get(p_libvlc_instance: libvlc_instance_t_ptr): libvlc_audio_output_t_ptr; cdecl; external;
procedure libvlc_audio_output_list_release(p_list: libvlc_audio_output_t_ptr); cdecl; external;
function libvlc_audio_output_set(p_mi: libvlc_media_player_t_ptr; psz_name: PAnsiChar): Integer; cdecl; external;
function libvlc_audio_output_device_count(p_libvlc_instance: libvlc_instance_t_ptr; psz_audio_output: PAnsiChar): Integer; cdecl; external;
function libvlc_audio_output_device_longname(p_libvlc_instance: libvlc_instance_t_ptr; psz_audio_output: PAnsiChar; i_device: Integer): PAnsiChar; cdecl; external;
function libvlc_audio_output_device_id(p_libvlc_instance: libvlc_instance_t_ptr; psz_audio_output: PAnsiChar; i_device: Integer): PAnsiChar; cdecl; external;
procedure libvlc_audio_output_device_set(p_mi: libvlc_media_player_t_ptr; psz_audio_output: PAnsiChar; psz_device_id: PAnsiChar); cdecl; external;
function libvlc_audio_output_get_device_type(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
procedure libvlc_audio_output_set_device_type(p_mi: libvlc_media_player_t_ptr; device_type: Integer); cdecl; external;
procedure libvlc_audio_toggle_mute(p_mi: libvlc_media_player_t_ptr); cdecl; external;
function libvlc_audio_get_mute(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
procedure libvlc_audio_set_mute(p_mi: libvlc_media_player_t_ptr; status: Integer); cdecl; external;
function libvlc_audio_get_volume(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_audio_set_volume(p_mi: libvlc_media_player_t_ptr; i_volume: Integer): Integer; cdecl; external;
function libvlc_audio_get_track_count(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_audio_get_track_description(p_mi: libvlc_media_player_t_ptr): libvlc_track_description_t_ptr; cdecl; external;
function libvlc_audio_get_track(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_audio_set_track(p_mi: libvlc_media_player_t_ptr; i_track: Integer): Integer; cdecl; external;
function libvlc_audio_get_channel(p_mi: libvlc_media_player_t_ptr): Integer; cdecl; external;
function libvlc_audio_set_channel(p_mi: libvlc_media_player_t_ptr; i_channel: Integer): Integer; cdecl; external;
function libvlc_audio_get_delay(p_mi: libvlc_media_player_t_ptr): Int64; cdecl; external;
function libvlc_audio_set_delay(p_mi: libvlc_media_player_t_ptr; i_delay: Int64): Integer; cdecl; external;
// libvlc_media_list.h
function libvlc_media_list_new(p_libvlc_instance: libvlc_instance_t_ptr): libvlc_media_list_t_ptr; cdecl; external;
procedure libvlc_media_list_release(p_ml: libvlc_media_list_t_ptr); cdecl; external;
procedure libvlc_media_list_retain(p_ml: libvlc_media_list_t_ptr); cdecl; external;
{$IFDEF USE_VLC_DEPRECATED_API}
function libvlc_media_list_add_file_content(p_ml: libvlc_media_list_t_ptr; psz_uri: PAnsiChar): Integer; cdecl; external;
{$ENDIF}
procedure libvlc_media_list_set_media(p_ml: libvlc_media_list_t_ptr; p_md: libvlc_media_t_ptr); cdecl; external;
function libvlc_media_list_media(p_ml: libvlc_media_list_t_ptr): libvlc_media_t_ptr; cdecl; external;
function libvlc_media_list_add_media(p_ml: libvlc_media_list_t_ptr; p_md: libvlc_media_t_ptr): Integer; cdecl; external;
function libvlc_media_list_insert_media(p_ml: libvlc_media_list_t_ptr; p_md: libvlc_media_t_ptr; i_pos: Integer): Integer; cdecl; external;
function libvlc_media_list_remove_index(p_ml: libvlc_media_list_t_ptr; i_pos: Integer): Integer; cdecl; external;
function libvlc_media_list_count(p_ml: libvlc_media_list_t_ptr): Integer; cdecl; external;
function libvlc_media_list_item_at_index(p_ml: libvlc_media_list_t_ptr; i_pos: Integer): libvlc_media_t_ptr; cdecl; external;
function libvlc_media_list_index_of_item(p_ml: libvlc_media_list_t_ptr; p_md: libvlc_media_t_ptr): Integer; cdecl; external;
function libvlc_media_list_is_readonly(p_ml: libvlc_media_list_t_ptr): Integer; cdecl; external;
procedure libvlc_media_list_lock(p_ml: libvlc_media_list_t_ptr); cdecl; external;
procedure libvlc_media_list_unlock(p_ml: libvlc_media_list_t_ptr); cdecl; external;
function libvlc_media_list_event_manager(p_ml: libvlc_media_list_t_ptr): libvlc_event_manager_t_ptr; cdecl; external;
// libvlc_media_list_player.h
function libvlc_media_list_player_new(p_libvlc_instance: libvlc_instance_t_ptr): libvlc_media_list_player_t_ptr; cdecl; external;
procedure libvlc_media_list_player_release(p_mlp: libvlc_media_list_player_t_ptr); cdecl; external;
function libvlc_media_list_player_event_manager(p_mlp: libvlc_media_list_player_t_ptr): libvlc_event_manager_t_ptr; cdecl; external;
procedure libvlc_media_list_player_set_media_player(p_mlp: libvlc_media_list_player_t_ptr; p_mi: libvlc_media_player_t_ptr); cdecl; external;
procedure libvlc_media_list_player_set_media_list(p_mlp: libvlc_media_list_player_t_ptr; p_mlist: libvlc_media_list_t_ptr); cdecl; external;
procedure libvlc_media_list_player_play(p_mlp: libvlc_media_list_player_t_ptr); cdecl; external;
procedure libvlc_media_list_player_pause(p_mlp: libvlc_media_list_player_t_ptr); cdecl; external;
function libvlc_media_list_player_is_playing(p_mlp: libvlc_media_list_player_t_ptr): Integer; cdecl; external;
function libvlc_media_list_player_get_state(p_mlp: libvlc_media_list_player_t_ptr): libvlc_state_t; cdecl; external;
function libvlc_media_list_player_play_item_at_index(p_mlp: libvlc_media_list_player_t_ptr; i_index: Integer): Integer; cdecl; external;
function libvlc_media_list_player_play_item(p_mlp: libvlc_media_list_player_t_ptr; p_md: libvlc_media_t_ptr): Integer; cdecl; external;
procedure libvlc_media_list_player_stop(p_mlp: libvlc_media_list_player_t_ptr); cdecl; external;
function libvlc_media_list_player_next(p_mlp: libvlc_media_list_player_t_ptr): Integer; cdecl; external;
function libvlc_media_list_player_previous(p_mlp: libvlc_media_list_player_t_ptr): Integer; cdecl; external;
procedure libvlc_media_list_player_set_playback_mode(p_mlp: libvlc_media_list_player_t_ptr; e_mode: libvlc_playback_mode_t); cdecl; external;
// libvlc_media_library.h
function libvlc_media_library_new(): libvlc_media_library_t_ptr; cdecl; external;
procedure libvlc_media_library_release(p_mlib: libvlc_media_library_t_ptr); cdecl; external;
procedure libvlc_media_library_retain(p_mlib: libvlc_media_library_t_ptr); cdecl; external;
function libvlc_media_library_load(p_mlib: libvlc_media_library_t_ptr): Integer; cdecl; external;
function libvlc_media_library_media_list(p_mlib: libvlc_media_library_t_ptr): libvlc_media_list_t_ptr; cdecl; external;
// libvlc_media_discoverer.h
function libvlc_media_discoverer_new_from_name(p_inst: libvlc_instance_t_ptr; psz_name: PAnsiChar): libvlc_media_discoverer_t_ptr; cdecl; external;
procedure libvlc_media_discoverer_release(p_mdis: libvlc_media_discoverer_t_ptr); cdecl; external;
function libvlc_media_discoverer_localized_name(p_mdis: libvlc_media_discoverer_t_ptr): PAnsiChar; cdecl; external;
function libvlc_media_discoverer_media_list(p_mdis: libvlc_media_discoverer_t_ptr): libvlc_media_list_t_ptr; cdecl; external;
function libvlc_media_discoverer_event_manager(p_mdis: libvlc_media_discoverer_t_ptr): libvlc_event_manager_t_ptr; cdecl; external;
function libvlc_media_discoverer_is_running(p_mdis: libvlc_media_discoverer_t_ptr): Integer; cdecl; external;
// libvlc_vlm.h
procedure libvlc_vlm_release(p_libvlc_instance: libvlc_instance_t_ptr); cdecl; external;
function libvlc_vlm_add_broadcast(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; psz_input: PAnsiChar; psz_output: PAnsiChar; i_options: Integer; ppsz_options: PPAnsiChar; b_enabled: Integer; b_loop: Integer ): Integer; cdecl; external;
function libvlc_vlm_add_vod(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; psz_input: PAnsiChar; i_options: Integer; ppsz_options: PPAnsiChar; b_enabled: Integer; psz_mux: PAnsiChar): Integer; cdecl; external;
function libvlc_vlm_del_media(p_libvlc_instance: libvlc_instance_t_ptr; psz_media_name: PAnsiChar): Integer; cdecl; external;
function libvlc_vlm_set_enabled(p_libvlc_instance: libvlc_instance_t_ptr; psz_media_name: PAnsiChar; b_enabled: Integer): Integer; cdecl; external;
function libvlc_vlm_set_output(p_libvlc_instance: libvlc_instance_t_ptr; psz_media_name: PAnsiChar; psz_output: PAnsiChar): Integer; cdecl; external;
function libvlc_vlm_set_input(p_libvlc_instance: libvlc_instance_t_ptr; psz_media_name: PAnsiChar; psz_input: PAnsiChar): Integer; cdecl; external;
function libvlc_vlm_add_input(p_libvlc_instance: libvlc_instance_t_ptr; psz_media_name: PAnsiChar; psz_input: PAnsiChar): Integer; cdecl; external;
function libvlc_vlm_set_loop(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; b_loop: Integer): Integer; cdecl; external;
function libvlc_vlm_set_mux(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; psz_mux: PAnsiChar): Integer; cdecl; external;
function libvlc_vlm_change_media(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; psz_input: PAnsiChar; psz_output: PAnsiChar; i_options: Integer; ppsz_options: PPAnsiChar; b_enabled: Integer; b_loop: Integer): Integer; cdecl; external;
function libvlc_vlm_play_media(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar): Integer; cdecl; external;
function libvlc_vlm_stop_media(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar): Integer; cdecl; external;
function libvlc_vlm_pause_media(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar): Integer; cdecl; external;
function libvlc_vlm_seek_media(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; f_percentage: Single): Integer; cdecl; external;
function libvlc_vlm_show_media(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar): PAnsiChar; cdecl; external;
function libvlc_vlm_get_media_instance_position(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; i_instance: Integer): Single; cdecl; external;
function libvlc_vlm_get_media_instance_time(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; i_instance: Integer): Integer; cdecl; external;
function libvlc_vlm_get_media_instance_length(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; i_instance: Integer): Integer; cdecl; external;
function libvlc_vlm_get_media_instance_rate(p_libvlc_instance: libvlc_instance_t_ptr; psz_name: PAnsiChar; i_instance: Integer): Integer; cdecl; external;
function libvlc_vlm_get_event_manager(p_libvlc_instance: libvlc_instance_t_ptr): libvlc_event_manager_t_ptr; cdecl; external;
// decpecated.h
{$IFDEF USE_VLC_DEPRECATED_API}
procedure libvlc_playlist_play(p_libvlc_instance: libvlc_instance_t_ptr; i_id: Integer; i_options: Integer; ppsz_options: PPAnsiChar); cdecl; external;
{$ENDIF}

initialization

finalization

end.
